#!/usr/bin/env python
# encoding: ISO8859-1
# Thomas Nagy, 2005-2016
#
"""
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. The name of the author may not be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR
IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
POSSIBILITY OF SUCH DAMAGE.
"""

import os, sys, inspect

VERSION="1.9.0"
REVISION="31ab0ca823f7d0ee0c52c159d650aecb"
GIT="e52d1b4916375cbaae1ac19ba387a491b1c64251"
INSTALL=''
C1='#+'
C2='#*'
C3='#('
cwd = os.getcwd()
join = os.path.join


WAF='waf'
def b(x):
	return x
if sys.hexversion>0x300000f:
	WAF='waf3'
	def b(x):
		return x.encode()

def err(m):
	print(('\033[91mError: %s\033[0m' % m))
	sys.exit(1)

def unpack_wafdir(dir, src):
	f = open(src,'rb')
	c = 'corrupt archive (%d)'
	while 1:
		line = f.readline()
		if not line: err('run waf-light from a folder containing waflib')
		if line == b('#==>\n'):
			txt = f.readline()
			if not txt: err(c % 1)
			if f.readline() != b('#<==\n'): err(c % 2)
			break
	if not txt: err(c % 3)
	txt = txt[1:-1].replace(b(C1), b('\n')).replace(b(C2), b('\r')).replace(b(C3), b('\x00'))

	import shutil, tarfile
	try: shutil.rmtree(dir)
	except OSError: pass
	try:
		for x in ('Tools', 'extras'):
			os.makedirs(join(dir, 'waflib', x))
	except OSError:
		err("Cannot unpack waf lib into %s\nMove waf in a writable directory" % dir)

	os.chdir(dir)
	tmp = 't.bz2'
	t = open(tmp,'wb')
	try: t.write(txt)
	finally: t.close()

	try:
		t = tarfile.open(tmp)
	except:
		try:
			os.system('bunzip2 t.bz2')
			t = tarfile.open('t')
			tmp = 't'
		except:
			os.chdir(cwd)
			try: shutil.rmtree(dir)
			except OSError: pass
			err("Waf cannot be unpacked, check that bzip2 support is present")

	try:
		for x in t: t.extract(x)
	finally:
		t.close()

	for x in ('Tools', 'extras'):
		os.chmod(join('waflib',x), 493)

	if sys.hexversion<0x300000f:
		sys.path = [join(dir, 'waflib')] + sys.path
		import fixpy2
		fixpy2.fixdir(dir)

	os.remove(tmp)
	os.chdir(cwd)

	try: dir = unicode(dir, 'mbcs')
	except: pass
	try:
		from ctypes import windll
		windll.kernel32.SetFileAttributesW(dir, 2)
	except:
		pass

def test(dir):
	try:
		os.stat(join(dir, 'waflib'))
		return os.path.abspath(dir)
	except OSError:
		pass

def find_lib():
	src = os.path.abspath(inspect.getfile(inspect.getmodule(err)))
	base, name = os.path.split(src)

	#devs use $WAFDIR
	w=test(os.environ.get('WAFDIR', ''))
	if w: return w

	#waf-light
	if name.endswith('waf-light'):
		w = test(base)
		if w: return w
		err('waf-light requires waflib -> export WAFDIR=/folder')

	dirname = '%s-%s-%s' % (WAF, VERSION, REVISION)
	for i in (INSTALL,'/usr','/usr/local','/opt'):
		w = test(i + '/lib/' + dirname)
		if w: return w

	#waf-local
	dir = join(base, (sys.platform != 'win32' and '.' or '') + dirname)
	w = test(dir)
	if w: return w

	#unpack
	unpack_wafdir(dir, src)
	return dir

wafdir = find_lib()
sys.path.insert(0, wafdir)

if __name__ == '__main__':

	from waflib import Scripting
	Scripting.waf_entry_point(cwd, VERSION, wafdir)

#==>
#BZh91AY&SYK:)&#(MC #(E(a<#(#(#(#(#(#(#(#(#(#(#(#(#(#(#(#(#(#(#(#(>}TFl{\kUFnV}f>{N#*nhｼۻ=ǥa:$=놲v]k'`6/]sOW{#*^=Wfzàvh{ͫZu`#(#(h==(fzh2#(ԇ]u4@h:G{y#(Awm#*,4HRJT-(f@U*kOۛ\3zu5vȉMnV:mZ3o}׫}gfzޚ7D{ｻ˼l:e=PUZ:Hfbrn]oy뮕qXilD8:#*#(JUIBz#+#*t#+]onQ=7Ҏz:>]>ރ+{ҺO{w,{ifu{ǃkW.vfvw's]ںytg;{ϛdkM:uN\GڜAA[o|>˴ϳ}cv[lm_}ϼK}#+c%lw\Y\onkzuQEsknd1ǹvzu귫:U':p{{x#(t#(z{^%wwhO5lqow:;*w`>=틻#*K&*݉G3SۮgSIWAG[]n=$6&*||֚Vhw}uzێ={ݬǻŭM#* ١9F۽vngԽ12LU;o2nuªSw{4tJ}7ooמ+u덵򃻽gBƪӽx}h۾;n0`N[}ٟb#(}7cɫkkݸ*T&u޵l7q2{VfY;NηsnUQTl&ݸݩԕǈW}zޓ*v|Re\:ٛw3k9FOmaմڞv_pD#(#(#(&@&dC!MGHz)ThbOz4Q#(#(4#(#(#(#(	&FjyCU?MM&$~yCLm@C #(#(#(IIȘxȧhG#(#(#(@#(#(#( @#(M4h"zDH#*4#(@#(#(#(@	d#*&$0)?OSj*z?DMz #(#(+OksNbNC>5Z뀚IFb"QDZ?&_k֏o?)Ʒ>UBú	c'	gP (;\MXt0NI*zQy]ԫJh%)|ZU#+^5vV@*F$FUijKjح$AR!<hDA\"HcȄ#(m5ZJWSWtkV|5L1e,fFDMH2"QIX&2j3I`Dh1c-2jXѤMZ"ZRQ#(6Z@`3cѩ-Z14&d bT66֖֚ڤ)bM&#*6֌%II	YRIdIQi+d",PS"$TA5H4l0Bbc45)F#("Fe&$VB)b2$$CIM+4dāaRTXaR*d,jRIɠMdIF-LI,́Y,3`HaC&!Md6VI&*6(#+ (ѓJXa(c$i"TʈBlLԛ!!IIX1,0l1l,IJ3a(Ie"X#,c!dM3F 56),D	c)`#(%K$X*Iii3Hh&R4Y%&D4̌єѬPc`"2B()M	Bb6I3+HƲLfR!H3YKL+$l$%$,6F4V!RfHK"l`"̚S$)f,hIEJL2bLVMH6R#+QbbLI&Sd64hiF4$mc1L%(i$YS"D%&bZ !j-LE#la 2*,QQf#+J)FDJaYcL"Qe!UVlI&MaLRLȍh6KbRb#)YR3F%B2)l!!*QlFEF*6Lei&Z#*a$mdFKɲ	RFHL5V"IMd-)D%FX42d͓`eZhe"T63K[6Dkd+"TfJJSL6(S"6+Fm,Ii)65m1RQFѣd$*lXfѭ&FBA4Q5(mJm+I+VLńeMi4͑	b**S-46)M1*&YYQhfLk,hfd֖b !Hcl@bD5Z(*0m4RdQHE,TiddCDIFf)h$")i,cLB&Ɍ4FKE	Pm$щ3AK1S+1LRcL&TBTlR2%5&K(Q!Hb")F5(Ѝf#&dF$RЙ6 $!j54,lfɴmFC$1Y$%Fi),AFk$Ơ0٤3IEQҌLf3)Y(H́"	R`cF١4Y)bb&JHMbѪQhlFfa$E(6(&VYd) شd,Ifl$kE	Z()B-Y#+ES#PDZ4EdTţhɀhfPc)(DI#*(QdaLTIXT)(ٛd5šY ̨XJ2D`#*FIA0bJSflLE*2k$Ri&#e5Il[)&$) ԠҚ5DTU-&Dj5RaLȘҤE5,[&jJkheD5!FCZ)6hXՌԙJ$,&bfXڋJ(lhؠIlm3RcTX)4miQmD0&!M,&ԁ$hƵILKjjmMJ2FFL`k*fEE1$I2$kE+>B/jJ#*rz)?p/\I=sIeyzWi02izDчnJvDPb8tnD``UAUPQߩ\soŘkoI犋5ER5TkLH:#+j-Ӷ&۬-q*I](#+R2U^ub7DGd*Tљdޛ~1WޅsoBH;rJw;{lޛH*DbʺG#*FbVYk/|Z7J<yԶ#+,__[uLoE0hR)V?H4I-Y^}V Xna=SŃ8\?O.3biv#+9e;2QlXN8@Hg&#7i҈S^ {lQ˕#*5]8b)5L%QXiօIأFH7̲L*Ö ŪVrgu+$It5`K. ࢤEЕѰ#+R!FƘ<#+J)0-`⡄.Cv-Ur<t5aA	NpbmCJI]Cw%ݴU-$K,oLr(멓9LdLc^(vVc#*$:e?k* S#((FDLhu(."hXvXdJJee-#*\Ӑoߗ9L$tkm֍/νu%Om0ety"6b4SΑ^$s:J1'f{Oκ,c^9-#+Jd X|e#+61tAAi"#+½Ƣ!$ؤo;Z44srHJ}Lh[)FƲQԪH>х5Zv{w!,V,񊂈Ѩ֪Gu2vhd)%4@r6?%CEt&C@5[rEcH_6#*)%pƷb^.s\KWiM䢒%[JwUFe߾䅝ݷqRED+6ai )=A*X'Eec)uTmz:lUTRy"#[xU<\]\qs҃Ge;p;|c|=S_8*/x׷XJJaDɴ0gFژ0\@tCFWFΥ!C)hҏ޿W;]#++9y{iHhl'$pmRK,nDnu2h&7AjC[M"<4=n$'iWWp:y~0M0>hů'ĺ9']pz3.ʈMXw!jT@6`O$5{W)-&X} $nuag9ǎo6=ZwGχr]`V"L~^87EY4_P&A1.ZS<j7m9%w*$/@Cv]3û83^|3ˑN8ٽlCѝ!>"l=s1F}xoZAh!PtmG)6,A3Qz!~y~ĽgÎL~S:xC|Tg4!kY#*XEs1	#jHmsAM/F[#+a,X2vtSa霼?섒H+>BPX߷F3}&a;H%7ݱ#(vi".<aP*?iv+G##L_#*Pfht"՚9f'nCZxbN#*0G#*M#+|>j{iaq8orE	P)MӾ֌YUPSZZ)}u]MRCɡcmhZFB>_zz{y+joTR,QQ.KA?/ͬ\;ȌN_(Vdl[jV뛨u`ד܃kkg[uUq	5MKLBQ) x?/-(eR(2=֤Sa96]&*{Kg>"#*U/"yyi҇#+t\D]U##+NZ>ߞp>	>*#ܒ q$;:2.ژf#D7=\J0ളԟC"e,~ЙJzN>^8Mu|/a%{qɑdx3[=\JX>i5;+HES#+'_P[oZC6JGTұj׍-)4ߍXULUFyLAVGscHdӹqaPP'DYDQޘ~ף9,ȴaKR:3aa]{|wKa['ݢ5CzcD~H,9:dG_ęY7ɳDªGZ_pzE RϻBMb-z9zOκs0XxC`tJζ.\xl!7ȶ|sRAqhrB(*7vcN.[Ҽ!5GC"1<҂?3r(|*:^sJ!$/^\(MVX?֘/\4N&+#+ߐ/\>>ʷW덕GO#*/Rb˒uqתJdq#&88sECW̵W?sS&dB˽Ózc8 x\AMEhi۠4Z`ֶ0	TTeS-5(ǳY/ۦQ>ρ,~8=bsE<D@e6ia	A=۟j/*=R/&)eU{dUpC}rEBU/ݶ۪.NDLV5,"c3izd<'#*gY:|֬24PwĒ.h-$?0[Q&<+LO{l{&G#*ds-/jdR^Eq_e{WV㻇(;,:T0;tfk[7ifY'8M>W©Gٝ8iH0qM3zX;8{FEVn񺕮0 a+_WiGk2EF,V'LؕUWEr`spr}E@W$}PdP#ޛE"3=hƘ6d!AtH^mRGF2ˆ0*;X!r("&cR!BekBoW1aT4X^+Q?vq;*T16JC~q?g3=dk>3uBXb*,'PyԽ2́X6n@gWKXueRwgvٽÇ=f隫M$&uO+B~fՠowrBnl.TfX`e.1bU^kS2Z.?kzaF2DI/׋YtE&&1-۷%.rykpa5gSoXZK=yt#*pȘמk04nY^Ez`7]ƍ>'R4l8[qY!BQs51;?ETx-QQ5'[(T84՘-]=.@DfjJ%FJlTeM\'kK:/>XHKZb7Kgr}w}ggCOaRI<""S.@ cJQ?Xh#(su6peQ>=Jvd_#+	-#i~:We< l#*&mcF*H󷺢;T67J5P;a5ѾldiɫW],Z6P{?VqփE&UoY{}a~{s=8q!*`K);5Gjf_7E*dn&^TENoC8Q@>~Idf#*?oP-5}2ᖁnǾxj##+c\\+K<EE0#"#+X|^v*}vD#aPݸ;j8.H'|yx5|Pʦ8鯥ILK%nhvKgTv¶4$kKJmRoߌT>`9W]6кviu|Lh|aDTʊ8wtX)j82+?tjjI0kr*3OGH$EuyM]<ɽSZC2[pb.Pq#*v^>vI]Y>*q3d5Ws"ljj=#+\mke+8Y=	-O)7?~]s/M!R<$@TQ-#*M/4+Vzq}+h8r@GzDݐ9Lt#*im!'[9X.Q<7U5'3>Ւ+m"'@@]u~^ՌE#+b` n{UL_6̊-kS;TxPT')z5B<K>UA39dHotr\K$|a׾KT>90tVFw_|gWL)إyxNH'a	G?Q^O̻zxXJ<r۰3wݎ!Œo"ڣ1]mYiqCsI␳XLUNakՌ}Y:ӢtRor]Y`4Hn,dƞAӀa8i#*AyŨrSj9Zud]L(У=<#*yW}ʕT7	kf#⊥!bZ{7qgD>#*^6Ff)Ow#(a#*4nw8#+A7aR^e<jP3Mzg5J#*f|.<#(V#(R;ŀH!	8FА䨲H!Pq큇s>CFt,bܧ͟rsV4#('*!GS[Ӫbn/THaN='Ʋ +d٧eXkui$=CS@2^(s#('pø,#*"1!3l5`sx$b02#+A3VR.!CHb5 Du>:ɪ6϶(#	!)n:2Y9l!m*X@ãĎnR$`iU֡Z#<>R#+v#(fnI~Տu垚>$A#*!GNta^e<ֿ3iA#(QrA@9DhDY#O"F,Ӟ޶V>_]?\̰JUs"qC.Q򵀕#`jt?nZ)U,FO[N! hjkDX+W7F{;jh*@}ĶA}Z#(( NRPKCѝN̾ha#+<,O/ês/<w+@!$3J#(tyc	jBQJ]Y6%DjHoިDΟ11ۧ72yy;~/93bQ#("SYZyh&)]#*{aWJJSHOg"Ԓ7^'hOFO\(6""^mO歩MB[w@LR}ˡfz{jٙIVzchaLgqal"ÇUh33tcEk`,d>K|b0ߧ߃0ˑZ-Vy zy[NSSwk:c{8m=>0?;$mkळ޾{˃YT<o(-TC1h$Xgv"@mgy|#*۵yn+qO#(1s.[E2@.B#tL6B/Y~Ȉ1zo`)ܰU37Fp/e^w#*#*aċc*PtPي*5<h'Dj&ȅBa["o>6W=c9(Q~/\SVXq;6D3xn$v6Sv=2<JJ)*B/NSZk+aZLt$:2l$  -6uW*W XiA&*v\{V!#+3ӎp擲Vq(sstTܗMɜp~#9#+"h)hqd.1!R|ZH==u&+z=$NJiqF}*<Ew*1"("*358<1YF6o#(1alHE#(1z`#qV8#Qo3iVyl-4)s#AABĀbp &8"Q־_"e7\όU<ÞE"Qw舶?zբ#˃TYIҠCrT#(!fJ2Mqམ8lDsu#*gܿԎ׊D`ghJ,uHwGY樠XVJ(@+I)9`Y#+:dTiGp(\nGu$rzI6o45lc,T'T8L>ɧ#sJa#X=V\j.ϥʧQ#.=9X^Վ$q[7n</knsio%u"O:bՕrC-L76`2f|-R>Ig/3kS#(ݵyɥG!mrZ$t,c,-/,f*'ƺS##9(V) (-yQ5oo~vpy3IH#+,#+Ee1U1cCŬaS#`8t!ӅWprg64!ݴI 8OFGQI'cܽEQZvhfE$.h1[0buCknoމYwc}r`QI)fp/2uAO7&#%#(2SyIێbt"|+Nc\"3$|k 0/Pmu:3tC̕@gxoLitfLק՜hʭ#5'q湢#Z?C>DЇ%mb"sLS`t]#+hܘxfh$aBJG!i)cA<f#(!TRBJ0F!yq9#kJCTH6"yې2(J)0Xja+`auEz]MlJ"FXK7U'RSц&j`!IQ+Dgk~3d|TW{:i~}`7v4Kw'=s֛6RG,sƑh| i^d?vxuv&=.K1xVC\˸}/d%:rV޺yIܒ>U{Ȗq[%Z"64#*kY0kwThD*F4,}Qo-jL}*ҵ6^yJfl  S'm#**TP?<)eTw^iHhͺXAvԟ`9.?@jHJf[ݚi)]"Nc?Ot9CQU0KAx_ߦ#*ud9&YM\8Ch [?A??#+:|ۡ-YhxyW8kQ[gΟQvMnn":~M (,D rk7"+ ë QSJi#*EN)HhN#iicPb1Q$mq E`X@nBQT4	ѰLŉhF5D`!L	.7o:?-t$^b{RCX;qiOAk&9]|`Y;<C9C\bW8r'R%(TyrӅ3I?L^Ga7[%j`3dT=Loǜ0mOɼr˯EÂ#*ӉΡI=l,0	Dl)ྐྵ)2'URJl~+(QKSqm{˥OX5χ7eJ/V^v~1njgfד׿)2c@4$;|SevB,x?n;3#(+pm3")	Lml=lZf;}o)z߭c|'#\iceJHZk`^e0_aica5"2i_^[8>/l#+OX/ZK~b%O8>U=أD*l?#*$/bsF@B1?u[e&T:6uxV>Pj݋߉駴hю	ch1?qhok>yM**H͹5t49"N&F#*0vm9=Pi6_^i\A:Fze#(T#( P#(Aه{AxwHoxB*qU섹!09!RZ!\f#*W~CW^nAF(	Jx<Ly9Pmݬc3sw#1`zzX5:z˳?V՝c+Oq|ÔF[7R&JRĤeLQPRv'|>xVˡ`R9a/Iaa2#(Il=cVCI6mtY:O6W>n>I^p|u0װ._]\xK =E1&.HGs$<[y)<PX?Ms?ܜ^Hxxג)*SX1\E }v7np".WRxgWKHm[QnڋZ#*_#(M)(^%Ԛ}_g#(J@T|]c!ÝxҶ{NaGOn	yᛑE"*#+HӵfԖO\ɈRĢ3F){j([n*(#+[g0>D&)4C)Kjc~Kf]^1wV[zKw{nu~^ǡ~QeѠϧNv%r16`!?	%{&H"o~EzcRmy6KDbD#(UUDD#ߘϓ&K-")fDh#Ej@7?ii{W?s|	z8ۻi}-:OT3,3]L0u@!L1VJ4-TcBs1etROyByDl2>_9Ṁ.xGUb#+qY0~tCAӗι<_>)c#+anM72(5÷WgKg`0w|Rbayғ:Ua!DA	#+~Ԧb$&^T(F#+KcAG{#;;ny|oCoGB(#+l_>dJAy.~La01FBSHpi}WWD7=\ȃdZEοd覈QhR8\fv-{(\q֕c2]v폭Qdd:GAzEDUH#*tS>\	"/{`mKޡpjMnu12#(rn^,&kYtm$!mߝsǓ|iaqwɒwQZUOrLb+\qv BVS#bq#>by߱)T(W|P/r&#*w1	?F}6)7;ądj4n&v'?ع-nm(@csLRtǻXYE<hUSB0̅Ĝ#(S31}_#xi9q+t&)(r^B_B&8A{A2'vu{Labc=R6	dj44@baTVpڰSOeQ³4DS}o6dl_A8RWXcCX/SU&))e$#+#+B["|]/ǞayˀC|WU)-JB\!A%e}VXi|F|AfeFFcvC˳H'BM?LmWk/UTd8yʁ@RjhoW9wj:wۦֲ8ۗGE5{߲#+WKgNʞߧj-|8UPu17ˡɱnGZ_!M~a}ه9.:dph[E M>j<X@u<xsI	3H/<R:;(n[Sb*|M8pSLFPb<T]\ko,6٭uߌl;gRVWp~7Pr_N,2*32tw[K2u?)wThMr2+h5U:g]}"T#*}Ut57-US1y|מ6xshקȼLȺYS3ƾ;/MX5TVI5^?Od췮rՓCCB"ѐ.^m#*Iaǿ'tf|.GG,u}_sϘ&yW3^Av.c}N#QcwVU텡U+oqgmMFD#(՛.O+@ݿ>^s}熘9pwtq"-ڽ~Y=7Ga}Oe}N'w5:Q:}N-,78_}am)ZS`!ynKh}n_=,-\|wOǠB\IN W+($[Ȩ@Qh&6Q_9x_h?2U8P=ifߘ!ROKw#*?BPy(FAg(PJT_B:{87pTKAn]*PcC}m!<@R#(*(TbG`y*rk}O_wg6~1â%y[gF\kvyhc<@Qo ϛx@<8]#+cK]G?"=Y|O*0Ks#W_c!1rh*uWƵ<z/Y5d(_%uo}1)׹.gd?9=?h'?Ӊ#+q^>'r#*|\C/Yb[q;H=q|羙%GhߍDPH;Gz[gǨoG~F	 =@ьY#((iPL&|!`!рҒh$m.&#+<ԅ*@r:#+jսuנ_CLk0\ӾѼGZ"#sw+t&)yjuZ%	%Ar#(C&׻G|#*>#+ŞY t@raeti)3{#+(9%*88n3Ϯ3%c_oZ#8|2C^hºÊr9^z:0]C 6lt;w!(I:iOۆYCLrN+6anMf1"x?h#]FhCĨ!%Iѯd@p#@b53^'iv,M#(H=#+-#*h7rӋfUTS:St4Ty"[>]1~F)N=F?cTGpەCz<&g[Y_|[?g˼8-vyF\{Fu6bC<<]V[k#*LiA]JՄ^jusX)l?<0v#(P [d_vOJ<Dvw݀u"dP@S#*UQ|tPܾ\/lyY>d{QX{26V܄g,qz_{ƶ]c[#*mb#*%qzRIb4CcEp(!bGw)2GFIlAi6d0"hhn)#RA۱p4h%$p'̚}hO^+GN?z;Y?3aqA)q>-#*j9-WSԅaQxrEYqX49gq$ttFk0д6,*QP54cMɄuUQʀJ4=g}ӕ_elYR*X|xrVRDvWU ?;wt.In5Rr7UEXt~8RQJH6w]jT>>KɞbZA+#(p(ҫ_չ_By9-˸\'OSs=鹫,;yzt~9"{hG3#Cs#+z%_։m_f~i!FX~Ѓx!#(8V9a7M4V)6+iLSJx*5G0zsowj)&A[\0ģ#+LㆪPAcabbȣyjaYlN֡D^	^7j<.-rdI7)nTnELi@sQFy]6JhH`"agJF\-g8o!kAʅ4F#hij(Œ$ʇ#+DV>ݚL?TUdUE:T##+uJF!	 \3Hb	!U$jJ4Rx5曷P	\Ag_#Uzt/w'QBx?{~;]~>pV>3Ea񿽮<y58|P0)Pz2n:#+)R"Y;aAg54G^j/XB&_#+9ե澝<|瘰¥ąusXip-_$ߢ-GL=uiyJ\˒I%UUQA5XKd*a(;ͨ~휷5#qcwKǽD+^=,^Mi2MK>3mAt:3N76FDɒ=#*RAZYdyIZ+6w艀gpV$ѫPQJ1#(yCUM4T#R"5V't#+^!WT#,=WnKnot=RɁb(0H"3kVIB4=V]ƂcWb	&Ft3p33ta4AByY9^tUd+Pdh`q3(4Ej,{qix#M`f<*ڴs:5Ph696±VFC4FQv2="6nV#(ch|jZ}[qMNCZ9043M6ezVѣLNbu:#*!ڛr:3*8~_Fdx`KPXa	JU#*̃dƔ#+$<-[~E;#d*]D[BAPE<t5GjF1J	Amєǎ~)АP@ \C|&l}q+X.:)<nGz	ϪUg~M^[:syicǑVثX5?l*N4+1g΍x008若#(:K(Ӱ$dH5`cU$NPl(wq#*la䃗Lhhŉzdҩ-WjT,oo'lb!8F4&\SZ /ey?R~[w'VBY:xQZahxĚ	-(RQFK(>F;&W0MZtkK~u7NW2;tc֘Hy#$m2F&㈄sF,E#Pmk8#**{(Мk]0H٢6aR$%2Zau+#(hg^0O3K5CEZAVcFṶ3:tz$l]ԙv6N8#h{XV*dɚ2-Vd)QNCr-Nn!JȤ$cDtJ'_{tU&1q$#*.1NtAo,-xҭA7G=ݍ&4wG|<|-ˈsa<|`grx;oauGWNhjQ&SH$cwlmc<,MɗED\L҅#+RBHL`)ptzT[cՍ&iLKiex@gDs36k༛x|qic&m#(:frE2XAOaA7Vڡ[#*jpx6U8/$BH֎j˳P#*`wIp#zlv<}mӃc3Do[`u+ÌrZO:u=,pX=?me>;;J	3q2!Cpgh4-2BC2wŔ/m;ֱBSWNӁÕl1z[<Uw*3eo"x].#~ F F!-dZ]G%a"Gudp^.<tOx:"q1,9Η	ĮQiĆp̭bEbl{뫬b81X&`Ʃtf,3M1iKEXpW$#*KUdo`>csBAQy?q^8*b.:gRc@p%YW^J^l!DDT9QL?~-֗]>79yÈƋt*ZLI"c"~TֺcU#+f^-.& *RDZ"8V%so3sܲ"`A/ʹjD3ƉB#*Jf39>4'd#+1MPA[Tqt0;y&zލ+3xPk9!L޻C/8\v]OTrkD?g3hXyU5Φ΍zYx;7בoJ;h4-wKҤ:oU2}#	>i?#+vKYc\ItDXtx*PoM$HcQſvk΁Yt罝́FJqpi",U]Tn!|wJt^`"^mIְl̞#*2bYD:Y1($]qP#P^엄F!+#+#wu)5Yѐ$3s9*Z/8X.9pr= 哃Н@:_i&U<UzfWYoҕdw7R6XF8|Lh/cdC'	P_]^tp.-y>-ߓ3AnܔU4@-Ɏ@E^9y4	\	d.m,xJG%ub&(B$'?mc?垚mK.#+*i[2#(15a*bИGQIY֢8o$q8SE-hp3^hp`w_)ߟ_Wl>&hD#*uӸ+d)jlTaq/xv=H:ˮ:'_:oM`#&b}rK.܅(*h0hFE	E{Y},pb%0G"m0tOKyfݪ!#+2(llSߵD:3^"&cT"1a#j2_xTz-8޿ۂ廘5(5DvoM'vOŒ>tPMGL@x&I57esIu~'^I=u^,Gpqa	3C1{h٫i?s%"M<3CYr	^Md\"uwsANfۯR&Zs0v7Ky1{N:=,H!#+/mTst:}kfGXC2rC ~nyP	ːɐ&;b54܌5>ZakAstGUzD1-KhS9l7m/LFeF WEzDDE[^bLy)X,Knb+]3)quN%P".{hQPhs.?>'<{鸳+SW1yW,Q Hlz}]wWB½fa:Bj]ӓzy&]˷XUS<MJ=٨E7Ϸ]&^G+B"49``wozF=pkε|ŧ}IVOWyҋ׳oL5k۴9<$`Ek#M/&<ir]lCJP_;d͝[㢠۾wIA*?xlKq	>"T9&ui_~1:/Lf.yrˈ<2Gڭ?-7eiq7f(\:aYÒ;.}D,]an}-VǂtdMETd#+Nx֗8reLd׉sǏfUED3 |:+['ǡ#*\+}=V(ǤDNv6Ea'oY+{#*ƐG)fKW(Hgm &L<[Oexhv?Ø<ҭt3榐W?ή;?lyY{we#*ĺjzDx(&33׳)CKfm3oֺ#Ex:u}}6)KtNc!2y]ˋF$DBŝס)#IE&)as5"'^/XFP/ro:雪:y޽[=ؑ͏hX*G+w; ''.۫јA2aEڔZF*y]8Voj}U#"O<lnc6KE6{e᢭){zhvsio_$?/.v鹂{tK]Yhu5^dHO^id'B}zSHtkdʪ1MUGq$m,(<6Ř-lo×!C{?fEޢ's3X#*/Duv|`~y6B-O};1Pm+qvNOGgCE>%m54D1ߧ	`80gb18|Ԍl3uxjlJ6wSջ.3&6"{P(rQ#Qsэj*Pd5^gGТ^=k!A]@8h#+s-a3yjkG}."dcWmEhD~yh7zx.S`R⩫R\>C+Uњpd~T&s3[eZa3xשzug#+'&iLoENTuny:C̚l˶"neW%N!rW?>}5/۟N-y\3$Xm~7I_9g].pꪹm\*].uC9U4CY@ﺠ-&yj*ΊPTQUrsoyoRMd70ӹvw2sX]ls!o%mUɵDi{NWʊ冪h>$Iw:vaNxOOoθg+e9.vCOYa(QM?7n&F#*$Y[LE.{XPVWѿ^Guu`?O^Ub=.>HJWT^rTk'r;2>ʅхL/&Jt<yql4!}$]?ĉwsw]Fu?d#*#*.r2M(=0e2yK@q=$mXU8N:ͧĉf$\*<ٝ~R3/%37OgE'0C.I38o9Tp\J#+#(뾇bl7IA@vDp]"tnu/KtNl	a-k	8LMcmʺ~twAR.#+#+8)N#T,**>>aXZjKTX-X#+WNNj_?;LϤ:?#*m$_}tht*/v:	M	5a'6Ϊ\Ǚ8jqV<90oˋ~>4q趧ƢM_O]^,NӞOHccw&7pQ@¸ׅ&\+<yJ;,eU#+D$\u_)Rt#e8e7;3ij.E|~sR!#*Llk7#+ѻp\QM⸴Uof&?C9FMK^;LjXtm0ZN`5ߛL9kU%jK[b2תsp(m!禘cUk#*xNwd/UV%lz)p#"2D##*P8걈06KyuGqle["5~}{^nr8;SQ7rEhj6ӥ9GD'Ku"EcC>#+su0yܣDzGHdջ8YaFL1	)R԰פh,LvƅRqǁg@bfӶv\#*- Wεy-ZJWoCW,>]Ӷr[aqu˷ZuO):f!$)9&7X9 GXH|3ʗv;j릩~N:\E6qrQ^kB>*۫^5KUm{]KȂ-<ȒENXFN05KG(@}70UP{ҍ=s	m)]lpl:Sqok?CřA/I7+\΃/'OZn76RÄ!!%jڹmWO(K)U;!"ξ.6e=j솊\,=TpʻO%xҫbADT΋W!p&W88hMJ4S`j+"ё#9RS3v@ߺ0T%#Rgzmvij4zzʇʚkZښhnN)QC-\pZz?:2}x+R^;XݏEE΍EuQmJ#ǌ[^4?+)1Qn){kPNFgE.t-▰\~1=~zWPO}QsRZbmO+ibrOm^jm0	Խc~RL$W.)UA־Rfk9>L(eY="BX2#*C\2d,:Dt}sڝ9S?|xдh	N<yyl<Vsj%Nۺ	-z槊#+h;xS9ORvۯĜh\(ɹDvEbf-uN*Y#+gP>㥊h,7×EU%?m:9aWpW>Dܤ*,';ӱ/F#:rTvI<YaZ#(w{Pz>^]s%>55/t5]tku!ah,M](7jӊ=syLQӨΑ9+g8t}B.8#(_ͣ:'B\eǇs`1ȩ_s8S!;:]Σ\m"{T	Q@#*/+JNCEf9y]zԪԼtx\[K.."sKue-5.`(G2P3B8Ц5DR.MFШXJv1K#-gO09QoEBqwE#W(uprVV|$H#6\ܲ.ź|}:xzliɞھcA2]um(t{.*E#+c&ԛSNQxȓH8ϬP<Zda\'LȘv'}z	H*;N;z"+o~*|g320(n1>{]i7:#%t=׫E {7iS\s׏%=WSl&Tw{?ixcK#8j3}Όt&؄+bć3#sIpj#(r	Ǿcnl/w-]G5ݠD-,{μ\wr|}\BN5]7x%PA){@p+,x+k΂F/^Qׅ>Z_7j"-[u{qϚ9H#*ˆ"|͎^{sGYN:6J]] ~ϛNq5))o:pt:9}pcv<dx:ͱ@AX8D|QMAZ陾$(hlw<	9drCuo(h2k)̯/>7|!ykS|YLXБwŧNjNniecm98$իϏ=N0J!c5^D7lKg8 rURjY\?-#*Tj%1F6[E'j5":KcYpjϥz}n`ڂv:Kg0߅~\ZA5NV@GʤET PuR..`}:t	#+jo7`#($>ESS"+~W2Ohl1	.B#+OF}=^uܴ4`a̶sj]ҝà~:`Ra Iʉ\/ҏZP5'r~;t2ҰrK\2Z4P8p:&T$S!#+2r])BIC_^[3,/(fApu#(FNr,V_{|^@VߗU?wo;};?픷/N#(#+OA>~`{Q8)BMUP0(􇫻#+L&G`~̰|el./; r+&rؒ-}͊HMdأ[Euߵ%!D:r	p-˞>Luq6BAPH"$::;2tߡjmZ?y##*qeb_2nr#0_ohHVLV>/uH[fͺ#U8B#+O0,`edgD|JB P87nl|>b! .߈>;wǈ|ZCn]#nWMo|`ٹ5ͅw'SReL3k%ʔj]r}pqK@/N7g;?bޑBNWhpf*c]s相d>f`:lģ;s><.NPI-GQ{~x?_ˡrw2[\xe0tj3+mZxu!ōDN}Αw[)`QeP2(75@rӵc5aT'a)ۄݜ:9DŃ+'YlϱL/7PZ|YH.It(6$:vhX#+Ҏ.H0#*Q-9?́I>͛NH7>n~#*u=vÏviov64ܽI򐭤E2֮{yBkM#*͟):WZZE]{UQy#(ŲsyiM't(|cw<4xg$WK,9JJfC_V2;9v&h@wӅ 5v>.vqM^sJ`Xq="屬0B#*@3&.><pn2;]ROYR#+؊njfQF<ڦ9˳gBñI9#(`=bOp'dq6x`۔M@LZkS!?E	#(9&KkpʹĆY߉3V=/^lCh!һX$f(tPQ~[5hl5@S#+	#+ϗ|#*C?((BÕ߈p^RNݻhpa-K^oW;#+!թv!j-Mgm0/Gk7GuBkvĜMa&kRf:F#*zf4ǉK4CV#((h1		Q!C*S2^ j_.iF\FTWQMg;1Gmzk8`H׭n/F!]Y/T*xX_)M.Zakٹt9Ljܪ#(H<$I+Uvn s#P(R3G=M!*CrĀ^V.DoGpFc9(klioIcMuqH4_!J[+[M18d@	ڛ<}V&H,XiJ RO(j#*S1AN}3!ƙ ٭Zqr;y'/to>|Du%[Ӝ\S׍/u{Gcջ#IѠtE', <D$YGv688?:t2e&H=G3[5_SLtjbL9Z9JPӛXDPsxyA9[[~˸A"u1FL-#*|`[(#(qL|{큗]Ɨcc)Xsʀ!**rpP#,IWWdy!0#(U(3"dYbni)DMxpW;<yq}]'1tK\@	l`,d(gzYcAq5]#H:鄳{JiV+3<WiP; XBo#ktx|?`@tz\#'zFҜ#,Cu*țl'!uHBBJ2=#("Aq@#*Fa*۠pjmPsVT(wB;/=:b5a6+xc2.ɸg~p8>U$e 8;Oh ܍m>Np(	ApUR5wqJ<4됔2d#=Ƃk$*	F׳dg뼝4)fDɥSW\	&TtgDUΐNm{tλ1^NmFTA	#)N,7YIB%k	C"mX"(8KyqR޿>[<KٌB:ï|^|}&Fڍ#T;[΃Eo&=WTե-60ӟvӜ#~gÄ(*z#+Tp	3#N|?#*¬~5Lva+gn#*|K4b#z=p5z&.VdpOD^;rń2^m?%#*Pf6~Tڼ	P!>jGC?6c2>'djOԐ?y$ywþGP_Jo}^~!|~>=b2v!i(?3`z1xzA#+_9X)`)tj#+\E-%9Ĥ=Yn\IN3mMdrc7!b|kDM._1&'E%ضS$#*<4Ɯ`p5䨦q@`BͼIp{`H`UrH&Ȅ5gi_CN#*%`UwDcDP,#((	.qYEw~3UuFD<5v\ND J:ǦHl{<S̀TQmჳsr+?@v&Z`v{_h#+\2( 1pj$ab"c:b8(qȲ"ZSTlpn}#(`56R~)RQ$[)G1@S"Bj[/(Qv!\pH)Ei5>#+_B{%S/Gs\GCJqvXb'!K#(?h?Q4/@XVtpM#O!o-F<SSјPLdfCe9ިD~#+Gct~.A&eMpG圀l#*|c4wBW^>5d1snwy;gW&$۶ushVE!2|)?YRMq.jGV,dw(8.6N1ԓOOՑ^me[ufJq4;&bvxݏGTq1)#hQ%#(w4'#+MIOx8Lֿ[uuhEID cvdXhIc]8s#*huiAsȵ3lo#* IԐHE#+;IӁd# ؝a!5j6s@9oګ	hMhm.vCJt2"z6\st1(8ACU6P81H6]9p6n6F7F?#+f6NpꄤݿQ3cPgvz#G!RM+3/2P:iV8w5)qNGȜP;ءHP5em{lkK-ckC`i#+1cv왈:lR`6RB^5"rY	AIB|>.MGXa#*#9YR\c@cSϹ73gǔ#+:W{֏b<j;g}+Ij+Fɂ(P\<JfO?'3t|En3*S}/L9o/-JYIIoLU0EZVsw岂(	ݜcBQ7SAIY`hcq"*PA8@I箇4nw"EiLB#,TQca1feN!`u&/c(x(dX0Ro˚jϖ뇳겕GyQ7n"TӨ\G0z\ChlGtcH=dk(^)9:e,8#+dX#*;Ҭ5qBt`Vu?{쁼EwaΣR:f$}&aG#*7UxDy!@p(#ly(pi'tm\x_n/e܂(l!{oL5A.JlD)A'FО/_:P#*b:3d]#+ѻHfAP5TSg,Z|&#*.h椒a8G?&45i{#(n3~#U +`Dۿ#+ą+2lܞ&݌4lijT#Kdlwz^|N:H|;Uf嬇WWNN4QUb: $IiC;<f,#(WR~_'Jg8zz7YTJ46yي󫏳y49}q<M;j#*(N#B#?wͲIx=] qۚ@U%PKHSBH+N#*<(W%i8嚝́;t>#3l̍ơ~7e)&4hf!E<{9L՜,\HIE$A+&{cӥf粻|vl<RE3|K[Ǽ}oduFBzF fȈFXfo#(=Oz#*EF:wf4ۤк&+9M݁,=W_CG|&F+m۲|1{Pf(ՑHA\',Ld*'yXE"u18oS8xv:9"CcW泫"Z'8p*$ {$ј=v|JMD$𗎗%T97tV'o4&<?8Jsv*=qÉRJ7ŇR9l}U#(:pflZHtN^hOޠ)?#*;	rEl!}]#**fe=E!3d4qOfr#(8yab뉶tQY>Fzyܰ	)	nS`Ȁ[m3EU&&&i/wB&4啕99TUR)<q鋙55u{^5ܝ[dEySSd'(ÍM&Y0%ܠ%~#+0ߜ?hĕsഥ/i#*OчYPĨ$sw 8̈́ϫxf.T!;ba<8GUĘA"Wĕ%i#+кWU^ʯq,ɘdcDXN_mO#(Y{Rq#(Np;[SsRI~4f>{(|-*	̱mf>~#(ŝze	}[#*#*#(@_@Q0#(AwG?O`03QE5Yv-,)*G3,:1F`dݘF}ynqd3p:bb&!q_?i?WgtDQDyȨ!"|2D+6w19ʩi,]YViw9NAZ\'EE#(#+)s;s<3c{W6bq$o_Y<{|hRv~&N<~{^۹$&#+^^N}Jb*q#0"DCz6IKcr0[nn">#+Eݕ<n<]HL#(c i#+JP\To|4]'];YޏFӕ?F" ]Dq)A1IL~|fDo~h<kP:{H\ޗ|j<OD Cs>͋#@SF(?gϏzQT×'gD>0aͥdA0#+Pc[f&{K,8fr.gM!RA~^_I#Rhi"$X9qFZhDN$3Ņ2NN:9şgm]>mr<_u('MC<._w='az!Unb+GED`sox,)Ni AjUV%G2~@zݙT2*WBϻÑ0'#I0x[؟F 8#()#; Ƽ3)˅CDrO^c{t#+o u~RA?pxw!sEz7_G5O[Շ'-ep(@>9>C_Ujr|0}!{0!^ܶ*#+Q#*>k<9Ĕ_eH!d5WgxIoN>E䗿ɣO,SĠ=4fww$,}.o8[x)%ɧzk0XBQ_uˍ5Lb{§.s׳Dj?&da5~D/S3u!ȁrTKO#+U1KjB?'¨j#+_I&"`k}5T"-b#+5aOֹK@AHg#* G<!rNI4	~9H.@o" =φFfٳM~#(b>]7<ںU?+Vɉ8p"=ST*#(cUJe0O*mg`#( @ƾѭ7cywڡ'(Wݾg{:uWw_^J>R#*5*qkM@P1 wwENoߟ0@t~'޶(CW<>J)[:63PM#+we8<LN'VH&{R-/HI͖d~oc6@;`Svb/zٚ7Nlo#*:8l#(v`! צ%$ys=As\t0_Qf*ݐnZ8WTWwGENn#+I6sO39_bG1?ᏼLVk?8˘zVckc:;'W'N}cz. 4L=qNSeR䪙[0@~*0/1TPoEJ9l=Fm0#3呕AܵbV2#h:ILYu0&#+ɨaFD#d۱	XS2ytx'N&[FL1!+%|u:e|?t`A\֛q@d*/]Ut扖|b묞ΕTQ=vF<ULf.VDYӦ:NǼ)aMg}>6C;IK&5穪Fҡ$%\%vGLS)M#(%Ѩ/}ƹktZ|=/~fdpd/O:V2T4ǏhĺF1$:^Ċ<w3']H*(J4ݨ{,#+zx\OO'vzlȋ;>~hb#(Ά48r8GTy1˿S4sst#+6pa9>G;l.<Xqa-hPii:ZZ.<rfWFJվI8Vqj؇VzM#|BHA,#WߓPRXE|($A~{_]8)GY˺{曡e'j_Ň6#~ޱ?D)B	(	Q׵@ߗ[_<Đ)3}5RbT̙xKJl[|ߑ8R?hjoxVe@ǯs]^~p4:ĹK[w^Y#+QЛ4\uok߬ŮJC0OoHh~>^TxE$>X`j61{P]MMiF}ROeCtqNvb7^::qPZEb#+z^eM<"e%!Cx4\`q3G@%c?oW#+X椄s:vl}${(va))}Yi6pLYd	֞؇KӈM7ϫ'`crrC*uY!XHC8{O(m+rI=,Vw>>m2}D:yGT5&>C:#*(;}0g]i0jarz'ͷTW5(Y_z	H5NVcHfsOZyiPт+dz!D+<؆Ow2ET?o~L[]F*AUP437C{ug4bsYU@#+taIC薋B݂@q6#ΏqՏ,HG/2.08nqک˫h%H'b̂Q>ԥX)%bHxKŪ,Do> TQs(aJN&TlRY3UD*Oh};z_7R6+:> P({b9s_ul1!S7Z1x~S^ct5r,-#(<S\?.ٰ<n-'#+-9j󽭎8n vp?As_&W|]HC?e7Yn~ \CmEu|~`yX^ցQGZxb~#*>c*ޏ|H'(4ogtQZ(4(#+b\1_{EƜƚj>ER@X._^ސwZ#*5}p>}rի^A|hhnjje^m^?c|ϯ9t_rr[xo%?Mr*DIDGo9v#*41tWy~W$*}#sWoA@f,Sɦ"f~sҒñNw)I w0}VwԽ hvϻ=vj,TD8:0	Qqw=ao#("$ /--qprAMʢ`&ɵa#(>М*\Hzaё蟯¨CnvsxWzI*-z#tIQ=	DpU7ʂJs!JuRH=v狿w,aebTs#(#+(2m#uV#*Hw0|J#((RDxN]Gčf :2CMb#+`(̒֬/;ai1 o_En|u!ikj~br'(]JQQ|/0ZzFTr<tK#+dY.pNl?wnfqhpYeJ߉݋DAL.88CI!yMGˎ8u	AwP'@}~,Q; А@A!Jii}rv~e5o/3^TG/z9#*v fA_a)QƙBcҺb9_z(wA/_2 *BxSQEf@'gzk&Ye䞖1(7mp(&#*aze5-gV&9-{c˧IOil_WEPLutм3W˥c<AMxɢup&ӲMßB	\HB!O)aà#(m|ĠQh]nHXQ}ngع0^SEYo:U:H]TNdR_ӽ#mskձdL#5`BUbPv%2aK#(bB8@^lZEaV?TL.=Ks˽-.W"營K9D#+B]Jc8*w|cbșmQ}OAgWhCiѦ-N`fYjgfu+\;hO$=4v0H[ӥ󈄡=gP#+ˢ2Ov<q잼LgPɿjx|kOE[ WU\+KmNP4fu(:&YRčЂK)T`$3Sl,/b,Tp2BJYPe{݅@J4ѦC^,lHI'] $ XTDˈxYQ|ዠU~:^eY5?}&#+ư0Rc`1!, nϺ=mF,#(+\dO+/J9ԇwOoUܻ%ߏxQHT3G˶84֏WδwI5f[vW: )!aX\`NC0׵(.c@LZoSQxgys~I$t	Z2!J#+tlbizxon)?D6āl@ @Fr%*Ǜ\꘶cyp人((֖9AsICD[}جQx%7\ f;~zMf0u'R#*óHZMTC dh}vʢU5Sǡ7>1i9jM˜hqZ2#(Aaҍ0f"hI<o^BLPlDNbw#+as	c'XݓZ!ǡ#tDP00\aV^v>[#(GK8yzi)LD~zۄ_Gs<[Y~zuN5H)$.%PgrVܼԘ-MfhAh]U`rVcQCN#+Pc as)$xD	#+c]Mj:\XZ_sg;qbouXΞ*'j"*0aeI)}^ۤOROPVFŤO(5(mT3LX0"1մeѴI|[tf8_Fg@,3)jyܶ]$H(H@V;Ũ_-z{\!SJX@0ڮOKbq6 5<ձ|Ib+FGs57C_hJ%e>Uh#+Zn)̂`AO4"(ǓdUzUcQ_=&3\D@hَw*<2@0lz5<&J?G5\:]L+d7ԻzW4ukuN=)N6(	KClgs^M]*p*A@qJ%WC2*ѵ+TVҵ#(=P2Ρ.iPq7ɧ-Ԥh͞7Y`l{{QGZavARZ+@2G<u^p"u3N=ɵg_QmݯޙIaa,ڌ'D(2~V"ːwk4'xQf:N<4d`AC+[!UWx9'@k#(5Sw;ohoZ#+AخN:˝}!ܘNb@)%}м#*n&E}ZDFw(`4)4kpۃ]SA]*LhOœءuKƈRQY:kM#*o9T#+]Bi[LQD2LQP,Q]BhkzVoz/>O'8ַx0'lM'TAPZ~ݻGݟY?!OUh +:d(ENSãһ豕@SHBe@lb9@ٓpf#(~wzc-#|_: (#*#+>|D'|PԪw2#ylV5A$##* S+^dybD;G#EbEo$kN9m<L#(|!ϧr02vk|7דl7}?x^iJPhvwA(m;M!AVXY |޻Dgu*)U*R'01[W@{~^5j?K#(P`fCÆ6h`O$eO?ʨ+:#*EfH#(?A^=v74.̰uEQ;pxm4PLu7*n:]ٴv3KClקgRA~I}B% /V)suP07<ä9oK/9CQ_􀥁{CtYi^w& gZ}8#+R'ArLb^(}~ukz 1Nms?XVouP	Hw}v|f&=#+˜ODpKB#(pD##X?WF#+|-GC1&e&)U]P*XIpMGtX$g(AC#*0vDFXi!oe\߭Fib#*.3x`]#~#(6%!XT{QN"D8lM9($P`w"?(#'H_MW6\wO'HoJt޻N]M5IխToӴ>&fš4!H07=euƔ$WC)9NKՑ#J:dM"#U\0pűCt'D*/9W}$x,Q	`wykMpTA(hX$b+O~#(Gך9/U?m#(V$vaP$5zy+߽,ćleL<k_ᣃ֍s`kY$Gjs<))X`{*aME~C]:g?}i[{v#+0?AA9X~n.`S9f}V5gA<u2<0-ibjo%'i6s8 @2?7BvL P.z͍t:&`s)ghirXke#*J4kÐk#3<X)#+wn$XױqG0߼=|#*-fS;Dd@ۓрnF%nYlJ,8xávW>#+'Fx#(?1G5V'`ee!ѓR3=^wg4 u#(aQ@0`ÿm>%MyX:#*KBZ"jP^:iChb?Q-KF1M$.rw#+KWn#*#([X>;vm؉{)0\B9|(2~9!DHJdGJ#*T#(!#*KQ}hBpP1MѦ}gqN3P}m*`k|X}3&KgnF,)cXTLHM)BLh3vfŁ	T&[Y:G\1z&o1b2zJq.BCOH\z%iLWq<^#*Žz=)2iIfdNJmB5oC"z"U8to+ѓfI$$)1S5Յ̚5e5e{ַ+0237#*:(m(h	ՎF#6kF#.j*	 8d%)(Lz:=WoQ!؟uw"%Dʕ#(B2OF']JKW]6]}i#N@Cu-Ń6٫+߁_xW)A֝ȝ#+vk	" -RmX2d?c94,wyNRSYۢe{eQ>s&QS<uQI{k/vAT=@`qUȂAS#(nԦNk-Hm޲#("B#+٪>ð/Õ𠰳1%HOY!7z5m+/jn%o0î_Ȫ*T"Ϙco5] *ٻZ(8P>	gJLOkoh]p'ɇa;	!h(q[Zd#+HF&ÿ-fa4#+4hAp׿ME.$V #(#(&8\xݸ~`0zzqI'ѕ֠=Bgʐ*%z#+9V/ڇ/=1Oz;N`riaߘX"1bB=߶1;:}ΓT[[_j}#*;U`Y(pGx^Lc})#(@o8;Z0Fǉg`J29wN6?ҾEZ6躁,)kuaڪf% 4@-KJHĀ=#(}<_J>ྸJOzttQƴeLOV_=]MHz@I'JךXrl#(Y"'HAҊtX[CNG3p}*{:Ƣ5{PtlΤ.NDչf&	4|k!;NװdD]RFwjچk#*t3ug5er;;iƎP(p/PZR%YV"R>QC&s$qg^"XLHДiQ8kPL#+gC1TF2	"!g^m%3]b܍y(v<kM9op"U?wra"H,aBH[s:ʢJDr.UiAkT%i_Dw/.҉ 3':ݾs#*D;{#*^߂[7d5U(?=jdS[j?ĿfSCvPYQwQ 5tfM=6/D-FVzG#(tv#Nk`}美0S)OHto^Rkl50Gjڻ!P#dCf_m_]+]6} cbE#*:>ds]^SʿU߳^_qx{F_OQ #*F_0"{wa`s3{y/Cݫo!cbxnEaMKkKyr8C !wI"#!,14(zTt"fźI^WY뭣Ub[KHCA2<P!j5-~Gf7y{P3#c#+?&AH;!b aB_b'~)ٸLAGʍEuAh0"߭×C^6.HUOI%##*`>dHJfQw|t-[T &#+B tu$l1Y!=?NW7]z'{Nbgf"K^@,aC0;:٢d?84j6!FFM  AV2CHsf|ॅox$w<k.Bx7'Nꢒp2L9r]!̣0/iF޸nM9ꝖmfCn(4K&Ou	'\%tL#+Dʮ-5E"®SdxU!@""W:Ow]i?phVL20&jB^#Z4{MkfGli#(l;ujR)@`/{.$"IyE!`Catq#Dr/?NQ!.j@pPSq:KɄ{#;]:"PВ|buqА.4`!]J6CF1AIGrzagf$0$͢?Os#*A8P9}#ӳkѦJRTz dbbHzH C!3#+i9#+9Zc\I׻e A 1@\â^v.*Rd.#+vvfDqs@<#(}ac}0qk#(:pp"#*:?UA2ڎኜճASs@'#*@YE~{*`)&}T9rb"N#(atɄ'3$#*<owʦyc}EZ{xrN\U21Gqg0+Ei9:#)(G^2's8*(b^w;IclI=LF$V?sƘ-<ezeݪ8tGBdI4*+~LXWg2w*FXyw/ZS;N[:͆/WH\ )NkFӬwʤ$#(yA]ǟZ'D@`e#+S~ZR\`!:HW#(6m\.}H"%C:^&H5x)&[|'W_UaV#*duwyy9=zΣDaaLg=)	5`ꏱ#+6Δݻ2`>{'O<"dx#+)rNt6dl'_waiQJr#+Co$PPmԉ<o,\ =aM2#(*w**.xt m`L	>hgOZ2jfK9lqx3gOfas,:ʦw}axpuuT9@#(.V]աARս0>!pG,Crg$H|-p\Gt'wiW;9#(>6#+129o!""?A.x7bcPLP#+#*<N{y4#*7}Y:kюT#\8NB)<Ik-Eh,`Q1F#*w諲gC `xBٔ|@PDcyE%]P-4Y#*#+i]1D;h!#+M4G9s()xc`=I,VβL`#+Ɗ5}[_\gvy$>z%uZ?o"{5ΖspPK]y1Gg)~*9wk#+$s_x:!ĽOw:̫gm(mQK.UYY;aX pй0YjSskYD+mQ(a\ThTNL#(1I|67Pv#(SD̷ȑ~{TΪ9հI79NA7%?/'	oG&`?#(θ(W>#(@Lo-KFO	}`-CݫWZ^@$3Ȩe@q^fm*/a!u@4>#+}(ULA2'KED6AP{XЃ(:t:@`Do|A~o.`0uםsZˬm$##*,(}]Y:߾%}_P]>>ϧzW.ʍԀ Rڳ#+h &"4#*5c3l#o/.{O2dA`!Q2f}#*.B:xjai()d	YS?jd[5xCA[BQ$"$<&0$E4ի7l_`e7#+j,Whb87Cl`H8rlc@T?'OM}c+\d	#(Cٕ>`SM'QU+%E8E(bds$42?g]5/A]@}PhRZ,,ӋSg[!{u~F8i @^9vo:	:,#*o͹p*t@wG(G3cM#@N{?#(F$I#+`$0h)A~V?]*\pQ"o~<DA"L&KAX(P^B*u's.7LAaPJ߭Tp&LG9#(,UH^ܝ20.:`L6&?;:	cp>~2ĴTpC88h?T#n9jj2&3uMeg9o֝1}\Z&c.lcsPl:CKQ_uۤːP:#+Q"k&Mw퇘Kӛ5u?Oa\2HuPܢRPI|{Q#(<n}]9B`C	?#(IR|,JOۣl&TQ^w#T|7ۃ#*%	$I*;펨GV׻#+r#*KB/0km/#7m	cǛ#+(@X#tC~#`}ƊV,|nP#*`d |cq.uuj=-u<D#j/@%>HPݺZn#+:Ͻ|=ˍV,xh:߅s-W$9@I]Q_%K·fZL\#+54M`UW0+Whus/VM&D#*p_$)WIV5'7k728L|oYv:ߴmz\&iLi3e2sO^?c伙6|i#(<\=HuL45I|^EMʖdϗdO"5~XjǗn8M9;nBmk~j248h{85UKT0`"tT#*JMRT[醼vd&]j%Q~-MTelРEk˿@D0׎np#+ #+#(A?X뗺0b)j^R3/0hgS	CB\g&JLXȎO83l~h1TNXwDY}Ct\4-v҅qo]#OZ|*F#~_Cb+8q#AC.ȃ<ojeJCSQmzyX?'#+Gg#*b,h=;UCEqm^KAgM(|==&Y9hW1#(sh]*frR&f$-Ƹac0&զ\c$:Rg)3qxuaQ{7HlNX,#030КV=fLbs弽7R(A|oMc]{A#Lv&LDpfk^%yoCyhWGN:O8&!M&qVyAeQ3#+4'V#*D	x(#7*A{#*!)u4VQ\9o+Ɩ>[1AbQ6Y(kbX;)##{u#4)#+-O6<'F~(;7陙8^vB}~tALAIu۟w72KA^z*`]LƵ@nM8q:3#*|^d#+vdpͮHIH?n	<yM<EZ7:4A0h`YI.Cy1GI`zhyo.*Bl*.;7j#/A<!bCCٟlw?lUcRT9S\/3N@pB晦aBp=ꮯ҅8% e=l<C2n]hP<IРAB~k뷴35S$u_lH%8I`iMb j3Fj@E6`oA8C73#+!{QiM\ֽ#*xf]QHv򭶜pvП9=*uT'ǳe#+tNt'˞?3ʮ#(5@DȤ	"+#*iEJb(!V#* c"LZ(ej}򺿗ʻ[w-ĕĖI#*PS2dECBJ(? A[=ROh{D>'yQ?	!51 :}0!6j2g<x=a[!ir)ȿQVC10EaH=k#(HS#+e1Pb4$b#*-EK2h8<!]Mc1%&O#+0f# ?4Lb/yBz}41zrՆ&lqMݶ>ÄqVEYݕ<#+;'uX#(qɩ?n?zXUZd)M.]Bl#(p47<RC2#+#*dM|ݕXF"t8	Qnt9!]z:;\WzpN:Ku(f}YoI<mfI6޸|AV[:382] r1+thM(k{m#*'[~GpiAG*g{9CdC(&W!]zML,&#+hˣ`o,'P=)c JNRC]};xǿ\9\@!1 C#+#ia8wFcMӼ'Vfou.F[tfDp!p1L6XE-v4 Xi@ulLw*M`{I<\xCj+ܗ7G"&#(8=g$CQA(jl'#*K~32$z0>!iaP{=7Jt6zg8pkO05*2Q#+`p7k&ܹ&Ec>7Er\<#+#+k8XcI#*TWZ:6ak(w#*АvpRy"-^M-"JPb53@iU.>[L$<ufcbvM/`!,9M5ηh4jaU[riuD0PcK/C qp#+@XT,:2Cah*	"85INRLU[ydnVd\DLjbBr­TỊNru: 3ke1^f\y.ffe2*2fI*lΥ5[lׯ[Cb˜T4,Y.R0ij^<)8et'o#*y>{%3NDJq.yR=.7LLG#*L~0#*blO$0gQ3rs%ת-Q4K3qܷǗwwhm+ϱ-c.L=7ZE!fgI-sHƶX._՞UTKe!M6f#J#+ "":N::'-CQ,?6ۙv#*@j#(4*NXn7f되'(b>Ο#+N^y5'87:i3tY?me49D!	V՛M{CTt#*JB@ra;[։qBE7"iͱ.C,X{\4HnpQEqp32rD{QpM$#*.?-	IEd: 9A*kMa_#*Q(̤ `<}#-DPPֹJ#+؟:ctn8√]Dx11kqF_W3HMs(14`	*{ªXHTӰm9;&Ym1ll##(l|X#*kM(څN(nMdNx,wNܧg,Fa%.RSU2c+x3<bi3^%8g?ka#+tJM\B8)Ǐ\r]_>	Ѐϯ>te%4٪dQ55@ɲ˴b&@M}-o&9n#RӁc32Ƌ̀,N6Уkp.T\ӠYRPY.Cgo+/dGNj!c~kohEiBK5qʴ6Jq>rtD@˨2#*fຮM͕dc4#*(#+	?wZ85#+1nS^@w')WУ)0i)W6mi4dT"Zks&ÊJ	I\#*9<0.&xvp	N$ab2ٌ̝k=7<W+p_g^zyABPw#*/=7vV2K"	$,b@,'NEQf@EeA>wV~+U[jʶNaD@}W~_ڪ~Zz]h@VQ=Δz#+wyٹs>a|H BA&HbZ5M3h$A%;sAA-(b$B<)Ң**_	oC|#(	K<+Qa>?H`*P#(Qtw5$'YXip:C<tUC@I?Wj1WL@xBHO}4	`D]JE@6@;ECHl@"j޾@*&S,ԣRBEb"0Qً$W")ȣt5uv+;CTU5HIIT;"*|hH#(#K*]>ICS@#*#(X-,Nk[ʻJُB!n;dg!GL#(ʌ^#+Ei,Zmoؽ(nz#(#+""*"1 "F#(0#()_KQdU#m-PS#(²/P5 0#(#(آi?УRyoR/貒MݼzkrMK3#+$w.W5mni++$)KC}kº|IG!V*DEae?$dHGH#*,~'{NCy=^8{d*+:CJbnu\=1c-7	[K8x+؁I,lk-MOS #(HfbVz)bϏÀ{oKu'JL֬Wfjd=ڕŀ8yW8&̆Mup$	#haCKhg79`,._HcXMw~a\4g:ffay<MVO3nQ#(Vu]{BDO!.5~1Eo\nװ$RpUPk38xKa:22r3.QA+[)}T'%}W%TRtڜNՔrA5':^8"#*dO02EP)Q8FU*hIμ1#+\)R(>˥˴ܗ5,$:{:iι?W*F5T#+6RQnm-zU;1Ջ[ZIR-Ʀ[i5R*U"I1R")oI7τo8~7EI#( G#+A Š#(Xäƽk]";U˘d*xheɝDnB1Z*튡qbt3++O^F6.X%ųDaRT0̺OH&**WM(#(tNlᾴ.T2gKmK#*J҃)#*}=r!UJk^c(Jl#(cJV1iS-\Jf\ۛ%re3bɍR`kst6ߟWHqCh#"+H,#*:#([M@馍8\"k"hXOCH#+;DSRAOa"h'C|/k#(Cz$}D!,r--~Kw mM_Stu~&D(EBSlu񱈆nM*Z DeeadPr@p­d0%8[8q+qq~:v3HPT25h%CٲOiꇌA*l,"&s@p}omOu	*}RrYgh1(QELDcwA룳vn(#*'@.erEX5X҃)e;\F_m<~ϤP;.ۛUEvtrS]xpgːxauBF碉CD|9OӉ#*sCQEٯĽc60#( <Rr7#*P`Hi#Un/58d'"/ChyLJU8ogiblSy F	ZDڔ@`@̤zG;#(NڂS#(9V@'?IrWG-G$"%L`jLY4}FI$y~fAC <2@=!ÌrolT#+ )ꄰD}]CP0LpG3 E(,^k @1#("L8_s)ѯ7ɺkfP8PuRd}~ԘE+6xd0ڗL+pWe[8SVYhQ@qXӂ(-5֍q0sG{nz믗=t\I}R7y*aM߇(eU#+Z)怴ZB2mզ2Rn1H:	s}x;YۡFgpS\[wܑ:3RnHJ@AH$Z*}"<~1[jnQeXx^((9y6#*5ǻs)1qE#+=wȞ7܉>~\8N8#>#+L-l	UAfvk#(fז%SXS߷e@aBBض#+gs+Ex[MuCYk#ZXg.N,	#j߹2M7nfz͸6\,2gb~|lb=ދ^*4NG5k1 k	af^}0B(2nrS"-UJF؂cKF:J9,U=u=R(GLA	^IkָCsL1[!#*ٓ=;Cu/[$J뿀d&oσr}⦾ ^#%T9JChUMH3؁'#|a1*M,p\j͕X.@k82ءM>[tyTH/Nf-jڠh@yʱ0KE$ךXR%ݓh-kn"0A\XN8BSIQl\;5`QKPbH$&2Ze֍}5PFHXe%wEb峂+m|go%}tYm%F+QAK	V#+[ R1=o$ =t>7|ۦNtoC)  MFySLYX<LiD*kE#Nh[Ҫa(Cņ|*đV^h#*4	AlnO1#+y,p1d''5S$F֩"ABF"D@Q#+AREӕ%2ȍ+k%#(XQ,΅)3#(!}(	­u꾫XnjhiꆙbEx5Yǰv\7B5&ܔ47k/n"α`r>PD[--2X.yo=Hm#*1$xo)_̥ȏ#(?a BR#gT'h#*gjF,ٝ#*R8pdЫ1(_5"@Ah/P;j䚓#((PE*vИC#(f6SR9B.GT$B$	A"TdyN^v|CC;$5)$%MQ<Hij/40VU]ʪpݠNAt) K#*vDl#+P#bi59pIBæl2L^c4:X9!*`{w2m^qȀh!6`EĐ46P 6l	*`8	gj  (@k闅 d $	d8)_>49fy,"\$We`IT(ZKhVI#+	D!XCH`#KZ#w0pHR_Q kAR"FQVW[ja`R6],/p􏱓MEdN#*ab6_Lcٝh&xLpuk3pdِ!#+(Grpχ1Ai&IHpvS|lO#0c]Ľqō{S`=Phn$X0,_}{=&fϬ\{+0ErlJczy$(Di6(*PBQ9?QEd E:N+Y}<A*Xsa*dmdT]AS\^a2D'[ԘRS9"|i%0. x!l`)RR1a	.b+0H+FD"إTH]%Jx	xpi:;7W3Cp%PP*jehwBX,IígfDhqiqHTw#*b#*ܯhvt	;˪	UNddU ^:V6f@4=dLĦcpM;9[vQϯ9,O2%F>M1T~,0	-Hn6MHyb!n]yYH,aj鶵QʰiM'وǣP*B(:P{l88ha:3zR&W#'JY$@Q@ڑd"Ȋ#+CT]N`-jE:jFG,Iy4JI{8s\CW*q/{ܒÑ2͉JmY#*~#*߭<P*	x;g|d!-;a?;QDv34B^)6ݚ(%M,kyŨe*7.BZ.S!JL*@id@4;t2mZd0$#*^cRI#*v#+(6RC97#+0kș!͌1Q#*;$1HuDg3r}/L%2	&?2kxiWA3PNa$cZLc)N <wwB\|cF$wB#*cMf2\VӢij3DĮq$^&! /|Ue`58fDneЏA<uע<~Uq8lyYwX*<F-ީ$sp@ٲq\OYk>fZ?Ho㱠]_'5y}&7VVjL;"i0f|񵘢bN΁:>KclˠGc =>&׿)E@RBK 0ihI})draHF$H&&:d9bIPSKǦ#+Y*@#(絘7*j@)A#( hA@p٧gqCՆ~o+Q#鋓U>0Gُd$́"zfM;=ɴLSrG=RB%8M534SJژg5'S~ȃHYn۵$KEm˞-EU׋nmc[jZkskۥPN'߼=ޅfxo1A;MH#(=eyo9Vx￤aFJdY3L4&شP~wRfj1iJ)(RkLFܡZLhJfhS&&S2FdhEQLJeϺ66hR$ITfL,L"2`֘ز(X%*3iABF((f<#*wv/	@D+;6dGc8vpTB*aHKJ`s$,7DAi[X?xb\	$M28ryQp6f.mi_#tSb\crFHv`h_?gɮϘbah`X[@P^!B2 6i3edY(&1UQ"D4'm쪓%#*	}(KrǠYƛ%}1ѴI vc.(i=Fax"E#o!H	Nˡ>>N=G"T:a|ŠV?f7&]9=-P"XىoTBumUR5BE@TX g1<zYB8<u}^h2FcS]rDLF#p[~=/;ÿJv;@Chj(I-}<Ὠ -x82X(EQ`-so0dGQUmnQt8ۭis<⎘! dX.2B~!}ΘƐ}4 KAn5أ)Pʥ=O=҅oNPZ#x.2'4uc	!k#*3idmw֒|C.-"ևe$@M:΄p?7nܵi<vsnJ5Ev	U}W=V>Ha	J9t$*HaٵCd!un2c>eQ,FġCN;1.0JӼ==ʁU,F@aM#*ٸwkEI_e2h$%C<pRs#v6&n	ۧj+_0#T$G[+@}u[P??iPdh#Ƶ##٘6Ԭ49C9FG^Iަf~ܵoUϦ7mq9cw]2W79aM54ʰik5J45cx[̝rLML4{7wRh41ב`N:8f֫"?#*0&f3T~[Ȗ,޳+:[311֓kTyb!zT\"a\;^0٣7Fg*3#(g8ZaC!@aw6K.Pi,ʁr^q0@@eh|bxvvhyAۤ>[MYY5WRSptipc2چ4˷Ab̾Axɏ3q x1öAgZ#5OK=阤3irE~io^7dvvuHGh,M)Q΍Md~шsyzPx;4+w.uTgFqxe@I&{vhPs{yO]cY'HkI:z	Ikr'qK,7xHY'fe88u>8:jav$=ٜ1y(}+xz)Tdm"MLcU4ЍcY$kVGH-1m!LΙS`#+`֔L4%pd"^~!ѥCHTr9îz:J(DXj9X:>s(H,bj6l\$s<E;<)xԣCC^Ff*^r2x3I+/QBdr`wĺ)7elW.GDtL:#~Mf6%5籺.6̬\*Z^2Bq#*=lނTUCF:*/9!Fes)tkO=Sdx7Nئ!KcCVzSljM22H).6E.6ȡb<P,Z$%pn!<Cڪ$fshAP;N~*p`Y9dHCËmo[?#*Ov-S}%5ra69os2]7ӂ0N$SlH37%n}YεX#*o"#iUɅW6=jMݑ{̚71lRD" u꼾Ylfp0mˇ&e<<AζK	]n3Qq5x{1q+6WZm0$ᚳR`A؛q9ohWGH4q:jn2F6OSecfquNF[5wSXǒd1;!A3Z5,Qds]#6?Rli0RhxlGpAđh.Ŏ3ui.Y+5S3=_H"nLJ&H$üj-HSc:>r[#(R9*lSPI#* #*ZKjsEսIL$iT\BGXY8enrm3dV"&\Xy-tBNV'4Z7]J#+WA\iljR\gb-C'j=IDs>8NHh(.(n7SNbvn}Ta fPsA/|#fEb1`K#+~L'wZ#*P4yãH`6HaFJM#+Yf(Yb-f0IS[û7IlWG))"L䠜a/Jd%76dqI>|WC v~cS+/])x,6уM+&pL*AlgQY)\c#*MBc؃w"ӧ/FLqП'2t#*,b1N9|bqNjU͹58Y0+4On9޲0lxw`xVi5;@Fa2g@Xza!N+D!(p#2Q+dȂ)ur.~0)4f̥0PV@	c]`RRS8+&*8T4m١u-*XKec";#*&0B`uh6aG"Q0cە9Ja$q3$@8Vbizv7#*Qb^.ЕR"C#(#q:MC2:lS8D;MJ#(5MNgSo8I3+5(!xl0A$[3б8B	;`U:I#HewJ[#*F$m♊l%6aVV%8={RP3'Cf%lFs#+Nl^vTɘɚU_K\	"B*MD	0zR#(_#+=Wοݮk206 A|C!NPgT#(q6jR8RA DLJcLfI%(I*Aݖ0ed3Qr'>}8dyGOUeb\&"#SlAnR]KKIiRk6k`٩F,Bǰ8יus"h	Iؚ#(L\QEmK)A#o?۪Q[4J)9fk_jMVy)5M2#+8$kz q+PZF>sHD\!>n~!ҋ(.ϯ`b\-f,n.n\XPȗ"!LGCЄ<	#(OdXnA6n^ @0crij#(0<Wt3MEQuM/_^6<Lk	S]m1`0d)\m$O&PPT-#*cHAINz;Q#XN%ɂČώ:@J!h?9#(~)>U	do$?kԯµhIkbF6[lf%Ad!L	G>	`xgY}][O==ˊb;"p>otXDKY	,o#(W#* br0Vm` yQi;kְ.@)A>X#+#(jdhm6vY#+2L>j#*W&`ΥqPVքYb{/MkJ%Kބm#+d-JYL´fhh#8bd~Z-FXMXT`$P*.uAi0`ap!ZPIMKLSz-.]A!Py)Sz)ZD<VkIZYy3ƲLhi#*,k,<Owxܣ$DK@*FY`&!SOD#+^#(; #("Bl#*ϭ:X|x2x`jO`QZd+o\.8+h#\}0=nu8P.RwI[LQvc6]!2i飖ڻXE`9#+P![NAfsYhK4k%4=:.x1$ew݂O-1iE'p$Pc#*մ#*l`Jvr5Ѣ2rMJ-V1#JiQ"juY,qAbBXl!EH`0R@HHU0ĀBb6,&jB@BB-𹙬Ӆ̴jhb+@(A" p״,zyB[^ZM8Qb{(=Gt'(!'(#*v	<\]#( }*yJbbK5!xC$Q0LHH?!UXi5j-I#*0`}wiOrab\TT?5K<bY,,կq5:ŮÕbW"ŝt"4fL-LRYk2aV)l󋱩jΰEY#*kC02yۏN3AjKu30S025O.WnLSIVx#*Ik.ft)v"ģq-+b2JtؿInp+ș;cHvXV)O4SΆc1*CUCMkrW锧5}6by2V\xcuAE$$y*ղl0c1Bv#+0/m|^qvhݕKr͑&06v2*R*7*`аelJ ȭIt)Bb{aRpluqL`;" I5RPm:fss]LqMnd6Wi5rRQkDN^*BmHHK2"G*ykvkxkLI	I6V6ũu6VR&Te>w	2c	bDFqog\yhE3PbYLCAB6F#+]DJP:`m"GazrzHFoN,;8f3gѐqԏ8%PfR-`;4yKS[t#(#*LF<6ӎipwyY`Rk0?7"%@VHh0A41̠Kh$RprsXȩ#*X-3=XՓ~P#*ZD*V9T;3\*A2܉` C#+M[_'Gc;Y#*ZWrQǣGY;Y9OV#*f\R:S]eƐs	E"RrB]|t.+!͆Ą6*c#(akn	Z6bPLwh?H#()H#+=#+yO3Qx'mYG3Gl,Tв#(կlmDDQmfRzDI$5j%dɦhfԈeM2R&2WXf)$QZqFҶWwKPrZ^ݻT`ژъoԶWXi&*m[d&٪KF$Տ<KM3*UՖε[c<[e䔪\&]ek2bkhMkkVVW^8;%`lv,#+9E]r?gz9&c	n$wt[C:`}' /{ck Ö#+#e4BAV*ZZY[F)MT_~ZlFҶR쭷Kkͦj>^RV6加+u(kDΛ 鰡Fkk婫Œ-̖Һ0j&iS-d)&%CHͱ-(ҔB#*&S,lFel6Lhllde+EJl(dڌ!$mTjͦ!BL`M2M2QK5SlcTIVDRɍ&ɩKljjݪҳkMi,KZl٭R֒TZڼ٪-Ͷ[FKc{*kjACIFgOAцǆQ1(nⁿn9v|#(ywj]J&g&Ҭ"'{v]*#*/a`||AYD0=0q脆>#*hF+1͝vf͵1.%TyJ7iCRb]W,O.:Pч7كBbȲ,6hH1dq$^@7U}S#($A~ %;ݴxC+Xma&d%O̧")e~$D"q!XJ&:k廝ϯC+\\k"?.yrh]&;0(QZ%[c	fpHΘCI@ot쐐 :ow5ipCHlXGgC,K<!Q.45_|ݧ*@#(#(+ljm*=NέZ'ΌTAI"{=p]Ci<䤱O3$A,%(&I@;#*߀òiөںOQܵ#(z3wغ|kp<k"F7#*As"oY9ΨgU(QABHb?)(iHҼ諦ݿog7h*b&cD2M#*`\XC@Y`Vjm86z*DsVY6"1VW(̎6cU։UPYI(-aq)#*JRj`@cA^8,wP1mQN@'Xvk@iAsX 8E#=~f9Mޙw#+LZRrӷp@%Ž`\T/htۨ?b53Xx?G#(k1eV_P=x|0@HP7LAU(|$.BpRUMmFktBb k01m\bT5wq:1xb=΅u԰ԃBƕ^sqɔNf"KIL[A|	cfkBu`rN8dGޅ0iLH1-I9h%!iCG+!MDTX.zL/Pj {>ٛ,;impUX0EsQkXi<Fu83D1#+'ʊ Нѫ{<$l߲*tSjJ^Pgs<&ܼz>Ё*PQ481D=d\`\ǗCwsgGe'ODy<Ӈ0 C	M!GX5OjN3aQNr/C&BNL(5oV;rے]Utam3l%CQ2A@'.jWE*zX8gwY\i 8;g@X	QbD q"	^h|4RˀPk#(<ܱ@X,cTv$PM|#(\RB#+e"*3Wp(ե޻zL뻽f4j^͂6(TUT6b'`hSJ]I00@S7](Dݧ\$(μ])K-'!'ʧ;͵pnb$Q133+Fi~"|L,w1x']8j0<#(_A!۩]W-#mۏl:IHi8,ז)B-Ěe$/R$&[ı)@fxye%T	>|:v"ӳpM12jV**jyY2s9PdaFْH#u#(8J)2Iy^گUv(	ԩ	RE3Ӻ*K2-QRMuZCA:rԺ&CA=D#*_O	ϫ;.4Yk%=6&dh[~iѭY-`9ԙ<	05d`IQUͲ&+iQm[r"Z+^F/Sk^7-K6Mj^]|K\+v慙OXLfq!H,K@e<`=1HO#\IZ#(~[dO~F|,}`l3q|䢡!څ(rEBHg#mVgF;[Dynwl5LF5;j۠!׸euYrei8Nc.Yچ~^p#(CC0%zlMҕN:#+i)"'2ō<C$oWe߇6Pk#(h`0T#(*#(	Gh#*UWwU;vɮHFq$! H#(E=ACX%4p|O^[mo>_4 P3(3m'aɬ+ǚ#U[ߟ뇨q2M-CtKBrf. P3؉Ą#	̂os5STSb#(9>~3cW"HȬY01J Ȣ1*س#(BJ,\TQQ"mȆ#*`̕Ѡ@DGQ(Rq#*C<?۳7y$S=F@N)ԏ8	rH"H"4-_]韙o\Bûgu&k414ynJ	z	[]A[jA;!:K[ҾR#+$z8هOw?xR&Rꑙ}k՝|PZsU)-0__ZcHXa"#*M#FtHFF-ަMW?BfaPlBS#+@SdnJpMtotIUHAIx(@metC(S	it-#C E%.VXfW5{=#xѴ+jY&#+4oZC"f3$4d%2JT1+I#zHip5abrh%HUf.0P*T-!ުE&X9n1s[6&ܹj+$ƼOFGclPb3pէH*Ѽ "γ#*2FĸdsP,.*ĉ#+IDRqt.R&R"#*U=S#*IL$[Ls҃_3OPr# ck楶<jL3]IЅDg@bĄ$2%"ji,PġF'<C%m=x䉽AS@	#*o}hE#WP^Mek3~iTny[&dY2WW$Q-4V(ncV1m[%5]6"hn@E|(()E݇Y#( p:}y&\~Qg$EhQTPZ1S ,jwfe#n߇^顎zi<Ow>>@MP>Skc/UPHkyA,D%^RM͐ccb#+02V,E1DRM![o7ui$֤*Z!B#*$(<Ԭ~]Fhkk#(J.7Y3+,2"#( f)3ęd&RE0-$^d#(#(/7))``F4{teذ޶) XO5#*A%ǟiN{>YX9JJ=jDaQ#+#w.$q^fF!W4*Ť0#(/sG*Eux*Q]Rҥ-TYM*c[EeFiYORF0P"(TBx:x~]#(G(y>@(%vV't(K=mĹ#(]Wpkm;w̹(&cZ]뗍32a	BJ`r4ʑ8Q0c}kCT#+ܻ#(:I$I&hxئ>{u݂wm546Cv)?::7X3*ۚb?#*ى65!$IE'LF#R,نrbF6#*#+$(&0#*9$b JD3JRG#(ӏvOw#I!!(pCL\j?弄]:*?WYNShsgYfyec*膦N~t*ߨCo@H+S`	"A))4kMRlkFF3M~I]&*#*K?KmsU3*1j1Mfık5lTSVMKkEje,֦*HI$bfgy'pۀk4LpP1U:"RQP4jrQTZmskx6#+#*K^p:Gѻ!#*QT6ܣ.7B)QHe$$\J|~?A: (]R!YrTOsW|V@#+ 5}q^MzSHA0Q)h%Aln#+#(b<,v{#*5\Y"F5$sTH59ە\Hi߇T"uA$_y#D+{*e4˻{N#(DXc;5nI%|	09(O]Xr{!a#*AVI#ġ)L,@>1J<!t8Ys#ut.Il&㌢uՉ,մd$C\[ubH7o~+ͧBBSSzWeq9$>ORMX8-SM6A,"lALuڵK	DTFdLۏ?_;/_axHz ]d#(=j"``=b8ݶG#+T%R1wcҗDP!oJR a-#(0!0rɇ,C7G·W\CCKeUzvUƛ9P!ӕ3#(|9CE #(w}KϜjzL:o7#*Lxt.`07cqĩ%A@~76RMg^hDD0AH$P48""wQ<{,	w֝Dbȳ@hbCBR+|^2zFc#*D8`^]y*3 w@ƽ"ҤVJ䢑Jdܝw=(_U+[|{З&I!wyM[$év(Ĉ1T)iXE:wveX,AMmZL(5Eܘ橗	 aż4oCH jv2<Z?8v'#+}XU:jҹryKa,'3y#*L#(D$${ɡs=ƄiJ~[2k#*_s~HrHIl2є9Y]oD"°Mg8#,OLމЛ,aaak,@3dd0vɥ0>ARħ;(F}^ru8mȟOV3g3M3dpKeoXSIK9JF VF%U<	)m6릗m^5&fЂ	L0ʷҙ<ȭ#wt@76vu@&><ٓ}c&QpR@BA78i'e-I#*TG˗-#(fç<G`}@_KtD;$/KyK"[KtyvdTie%i#+QF2@ggȢ;:RAA&ěcbpm+c1Z#gȕ45X5D9ۻz+\.,ji\2/d^\l5E"ÔivUh7ah0t!JRPPމeM&LX ZA<a7QdmjBHٓ#*bv46i|="h69_Lszf13		@Dk0ipSc*@HCgj'MYg9#*'@LbW7a'JzDD$B͵vm4(%lFi*)W]bܶr-M_kVh!<.Y#+.mڦ8PAY!P)ie;\{ڟ[H{?!$gLa wvV|Kl&F#+VE^or|,5'z	&ɲ4OSe՗"cqcvXG&2jH<M#P4p78",c,y	-,S5#*a4#+g}i@1mDҚzrg>donߡsŭ9<.0ک	_){m)%{|U1ϳ P}g__p*jD1c44+Jn.tjlf|Lbpϐ6,ئrR4tV'ƅf55v1憎'$Me,l;5	-B:3Vue<00RI@	ןaCʻ>+b;8-`;B)©B,HZq@,3UUT"b/T8f[ֺ g}[bD#RU`H0n;)R@T#B*(!#(!BhaBiQ${1ۄ$եR(7!|'$|ykٛys^Ï~6X&@9O҅ZNղ'L8t(2Q@8qp<b/>`<qD:QNDeW`HXa$|NUJABjMV#(#*B1FD-fMZ-JJYkfZ\^.Iv|P+k-mcZ@!f`SHw憚"uL̎#+H[&#*4ϲFڰ8XL~	OG#r0.&D$݊f~4aѫǐjΆ$RYJfaZ͵G#*nM#+16f߬6Գ{mSV*B=Swu5p?L#*`z[=HXźGխmWbN֢\vK{I_NUˮb0CW)[PI5ɀT,Rm7=a؂Bġ?'XCR/XԈA>#+`xWVe#*$Aؘ^2!#*eht:hZc5L+oAPN	1NE|rC}ţ0{ކë"A#G^)gF( ?W?ylP0<8|7t3UpGS$4̸u'ז [%\4`u&zV#(	UjO4l^DagrmDƖ+j;a-0IP|K=.!;iyAH}UG#+LYp`cAIl`^BVJX9CbXG#܎cgņi2*hp{J&!;,+{k)S=,$}O&}uiO@#+TDptTZ#+Q8M6KQf&6x媍@&0FoѧW+FBZ@(##+@ʫpOݤ XUgaCHKԬ[pa_U5SgL|;i<Fo$$7vH11a<d#*'k#(#+hy+@#(#*Bt(9#+JxWGZL:f4q!818-$rMzơE"^rlAdRПrjnҋL:"q$Ϙ'+f}#(;0)<7t{8]Ƚe^#*w ZKxA4O3iQ##d",NPk#*ޫ^r#*ۀa1#$0MB3D8X٪},VQwvqwe_ALdվXAg>:/vZJz!gͳGmH_SSatCˬ47,ݦp%N:5bX#(_fSď#m&Yul+i]'Zvx<=g)u5Sh|^imHeZ0HFjCz[Z|tȽwRO­ynYk636F뺊yĢE#*YPi#*ɜL Jq=[DEѕ4r7WxytU"=3bO[?x#+E 6ds|tYjUΒ^wgn&6WwKRM9HbĨPTL//ooZe0eoyReL(Sk)X-3lFlSY&KKvu48Ҍ`6#*BbP!Z)x^)*Eޞ]f=%4SW#*Vn#*&1VlU#DPhǉW11VCnHkNTEZ8L4TW$YWlh{$q=[{ҁa2m#*ŦSn8QyzmlڽZX͵d5Br8i͙KUmH)PVs$J0A!0SiF	(1I(ؚ71ljgzREuIf;jcߞ\Ak5nBlWCҭ&+yC$_;L#*2MOSZCҙ~LV!NEup9|Q(;vyCOgHnRdlMl.J<LEXͷĨ#+0H#(#*F.Cu7,WHϩȝ=mLHh[LjxT@5.3)6IBO#1E#l3IQIfBo.hL:kJoJ˄V9lT{֦/={>QF=#*	X%H?#(`8CL4NTPfU[1HB= \*L-( Ć#*iR*#(0D(,X##$.%I.%&@ݿ;$>k?M =kb?dh4Tm>_Rm8vZ*6)PDD)dpE5"OOzshxkEl<MK#{{N!Y=Y]eֳS3:Wd߾fk@9Qy'QgC|h"bqrFふPcHm,&Ȓ.Z|_}`r:vU5v$>dN1!pt=zS{3T..lڮhLvTU2$#Dq3P^~$'\7ö!2\xkhPlFS) _Lɗ 8_%oM+a**l( |4lI*hؗ/j<RI!ioV[pU:6*Ư:WVܫs!/QNHZF#*m;ѪJʦodnmݱH,Y	-$Xz%4bl>2mn2E&{0nYR@,A*)@"KXyI. (E@lHAd,cL@0.]{|fYʹi׳jxROuQMVd)KcELE+VeFɱRLU6ڙE#("Z#(CH% m=#+CH}_R"(\1V	I!FA/}}zKz=.6Nޙᮦ48ƽ#1U2ZJe,U_k}U]/nj)n5N-wi)mFhɬVҕ5]UbݺE*~q9(Ji#*b($iHhAԻ0PlmGIu (	#*vN`C"OCR8y(=j{Gǅz54_򢰃AvU	4܄R&m:fQ)OI1I0A$Ld4 L3%Ú}SrxJ~{<Y6s+G@ʭu*=T#*mdJ.aU2XE`̑L'gRN|8^& !VƇ3*iw{=EBX}	р;;1۹Yy\EMll~m?wz`6F;[3iU$$7CPz0SS@aFAi-Tt#*3-[VOUӨKZƨ,_/u 5k__u##(f$#(v\):?3x}zzkdۍU*Z%(;PFhKA-ACGkmI*mꭻյoMd#(-#$SlE#(d(\מ];Kfmd"N2vZ:f],S#(`T#+LV#K!j&5166#+DXPkbiw4THE!0pP@rb^1m!1ADFYA#('qu\cY^D[TkP`q\22qeĜp9>0	4bafe4GW , #+q"֯0JWmbBSݞ_?'0>`};#(sgsgH?#(lpb2#*撃/~Hpq`_q|Y!@3,	2˗F*)#+h8as|{cM2-@7"4b=AvF~AcC]0ѹYJGs#I`EKSIlyuK/EVˋbTL t9u{~PJ~x&^Sd>Pp٣#(EN3*zQy/L:AB*HHsJU;h(BFF|p^#(XFƔFb(Et?w|PY4^ݯwF\x.ؔ幗&jJjn%bt4\ۛQ;yv㮻f9й]ݺEroJO&Nk2ƁͶڈUcmRrf.ۻ3Tlm9ŮԶ5@]U}i\5&H[=;ƁOڅwB@$b%E":1QX(6#(#*#+}Q龳_gY}bYvO#+g3aydQHc$#+iM43a7#({ZVYA`]irQ3&MX)he^^p(RTH2#(uwRŌMk71#(`f*_Dl'VS|$H]&H@(L-F,[魷R5@,H4$Q@Ƃ<n\(OVt;Xa~(0)V	F_hz#(؁hQWtAdXfSjEm*$/#(1ٯ`sV;%KR6ZI[jh$7!#a*&Z5/E#*S=jLD5\LP$W#6vͿI b*~}#(xѮ#+Br#*`1Ȑ3"+sEPDVوvw|b`#=Qm#(%?.Ѡ)I0`#*IY&f#+qP6&Pi	<PGiB" RaiQصJEJa<f4(#*XXKE[#(#+Z2"JL#(#~NKQT(|XʫCE"eI#(.F\7$BhTZ56Xis]מ\ͶJEEK#+AE@ f?)Ahk2۷jkjI5c^K#A$1+	%Z8]/c>E:m^Na$#*a#(N#Ӷ#*J*%UD&|ZҾ1fJէlp@FB+N$bHL^gH	{$?q!glzYWCUijhJ#*[\E͌d1lmk@wwޝnf6dxn]!0_u#*KBg'q*-5#+$m1#*%LG3GB#+XD=a*	Z7#(6OTYrDd$UQvZke#*!!QNe68[Pel}y'JIT4kMبdM߾2>C5?q[(4O}loY!;`"]ry/w"h//c&;յ[ ؤ`#nCXfg.7u٣#*#4zk\n$(5I&Nu$)p,fщEw'p+ݵD?g67hC 7CVB5A 8=(\K?ֆ1#+ۘZ0}B,*͎d*朄}1L~B$;%u6?AZѦ@`F	Ri]yw\sM^$WI0\40ekGɝĝ#*\Մ9N:@PbMε8JzugEX_S\S<OT:R	XvYx:K#*~8>uDη?t1e[ [&ӲِHrQi:,~L^e5^_k|W)r%ǛE	poLTCfyI#+Ue#cp2ѳ<>%PBxgi:'B 01+$~#*a#*DMtԱtPDxfB{O:}DZB@D Q3]2ݺM(fG+-մD(J}*1fj|?K5FUQeUVm{ߦZߡkɲY&24D^$gѪRƽ~s>ۆpi_Ϗ>)zbj;ܼXSPc^Yekь#*TkX{ BIaUȝEe6}1y+<q{VK	A3'	y)P tp,rL֋ uBr=DઃS6%Ȝ)׌4BSɠCHC(q^x/AuڣRols&@Aq8~_Ya:}rKbA$U@SNAl>#(?+a$!d(vl/WEﱶGc1mPӾB1ia~^F|(s.;>;3m/i#+F*fֳld}q`"ErP@P|wHđrW|+.F&]|T@aEGOb/EJHDHu(uDQ$HB;",R1g\<-=ۦ;	5+#*	)hV&1! 9+,qyJcER6_6H'R-T"@#(&ѦK<z L5텂8A}SA3:ΏCq#*|Epr2.4rc¬lZKC}[FdJ#(;{7|1Tb oMi(FLi7#+5u2Ciu*&$D"%X/Ղr$	+bY٘`Yb8G>9|U9)$s"_N]bS17eU8aՀ^1P|`0G.ℒu\!RGvAdBʄ8pݺD g@igJ~tB1d:˦|,Ry%&RGf9ưHH\w?U%6[)fŉkRT}?GiBP丬L;2t4	j$	#*7qbѴQW_F?O!#+M23dEQ-%I%SabhRl6PZNvj{Yg^=#*3|.'8뮳YgC0l8D#iDgPTaKmSVul>rf3VtV#++l8'z"TUhQKK,5:6dn(tk$256|2r\qrn].wqE$ xmm#*MQYz n7rTW:~/2}@@H~L\C8$55[_@ɟ\WԚn@R"$-eU1SۗW+zL뽂Fj	d#[)suz$yywPpX1mdm#(x%D*!H86Ư1FѫκʹWnPdbr#+1#(Fp4̨C VIR:3*̵řeWhJ2VB9t#*	e(8Q̜<K#*P+MaV#)âSCHE0^86T[6F	X:hz#+j@!dm1YrH`QVm#+:ymVf4$+@r)HaێDBY#*8xǁZbnEPlzFU+V,w"or6!$Mq`aPDPcU	`Rtn(1*Cqo9w{DeWFƃbjixnkFx3FP#(0)F-7Fزd-TqVAj5!uTN;|]H*791l3 #+P7kXxR0q;5 l108Rm0O#+7d(0R;GcuFF`)Zj#*b!l#*D(Dlԍ&D%#(5Ǘ']51hM0vdlIH59\@ZX6޵tmץW5ʙ./N2SU-)RX1#2*HmH`MH"&ת%z=3a 3eNMfkLΓt̓#**5CM*jl[n2{GWWmg( wE=]\DiӦѨ	(T77q[YDp*.`Mn#*D#(4HؚgS#+hF6(@Ki#*ĕFEI#(b6&(DH MZh{5JS6ҡLbW#+"MW_ٺWvܹwഔj-(Z6,HDE@jԂp;8AnNǶTj(A8hH:AuOTAJ8}U2sV#(dP1Ri.[Vw{$즡HhNn}l#*"d=-*I"@D<&iTT6KRR(nm\tԻeQjj(f` (Q`oU*nŔL!g#(ր(t8x9w:(ҝs;/j#+"B]䱮]g,gE&om$f`dT{Y/r|'`P@EO9fHˁI\"e	: ]̒j0~^ckY<.Br#(PƣbF:9#(?RR#(oG>S\zNu$2gO%׺h\;\v>#*&xQ`!kN1rp:PQ8Bu#*#+u`D4SWaC#(J&QmE#(,'-T|2Nlv|2W^ib#(<KN5!U!l,.~ѭê@;80mi8%4 MIN)lM]H,sMEWTe-A<utq9k[VMrymhƏ]y(U5Mjѳݹ5m\(zi"hPiW.t=MR٤PSSi@Mt4cJRD D*w(-^Ĉi#w^͵\>샼҃{R~#+9}"h~Ic@悑@*0HJIBH"iA-.NKT@[vډVMҵ%#+LkǁPvD"2 0 lS@@?5}tQF|L 78YksJ^#+&b~Рg֕Ԇ_9P=Z&/dA!@ZL͒E1K$KFMVEfEkl[TmTje[M^~i^y;AaDɌlDHFF88"'rJa1G$i#Et¸TKl+c",Dc$uB:0ZfnjVJiVjU`]&F#+#(@.VaJZ@!h1 RB6#d+4)P7T6@{1Sk=X$NOfd$*W@H @x~>(wok\Z1).1q@b(^@Z`@`%|q4n!"dS.:أiUQ,zzu!)d%w<]^YrfPqwUEkFD*.#(ϲ9E}p8W(PB{ndJwo8*\s'hQn[&;e,L+9&t^	Hqі5IUAg5tJJ[O߈;H瞷=< Ʋ˔/Ky/_T!1)C.PJrQ~7^rG6˷2WD'b#(uMo}\7\.#+vwE.}@:X2["25=w⭃xfkWa8s)TgU]!^jzS?'=q&IN7Wm|m'w㎯Msxl6O̐	C2g`AWnr9ܖnZ$ǟI?\4 #*$+cՌ,ze]`|1wX H$XG4Ր"Ht@~ڻx(e朴kD'tGP-VZh;ǮJ׿YJ%DOج#+&"h*7D5ᥘʧ>'vVBYǔL<-Ͷ׺V$nS<MP)ñm}㒥ytWn8\$"=~#*qQtIvrއa8<,Kξ*"?[M38&A3105q^H/.#.vr\TftX.-EPqX`c:b1),2h2Cd#+NYm HAW^<x9wsLڧ:^1<:oxnez<fj8hzxS]QDty;)G0V|;y<C;^jO*hdD޶[̐ъb="b!F#*j%粲;*" uʭf:zwl	[aH"tCP+yǬ.ޏGJ7[z'0<lv;#*_Lm0Cph=A`_+O1<XAc"{<x#*P#3NOU7]8x#+&b{[Mj)zrrLqئWSnpmT扁p kyJSc07Xa0A{'T#+Kـ)*1/cigԙ!"Px.:ăy/YE$օXb2Ї^H(SB¥l!Rfp2A8lNXrHoj@pl@ᱱ[namcDz#h"Ie3:P*^)8#*9jZ51XY頧$#(\,B#(! $Gt4G#&gV8坒̡ٙjY߂Pgsa$I#(,̐@0{l{YZ ZT2+h0rwV(j|ѐMPx#+0uE}zWN:ν9٩["p-SLU2s$c	k!6[cʞ5Ks5=}2濫DGx!.	~5T:aj<A^k=ce1d`~`O]#([cˋJNS3r^f!cߊ<q-[$'T]a%D#0SZ3oQ$թNe-lWU<<s,JF6Wxh-3na'L\֊e+ܴW`|HtGWo]ݸ_)1\q&]sѺ.ͳidRIi*:īQ.K`"ҷF2.5sֹ9tj&cfLߚު}1KKG}`#g_]lmXI˛F,D)bijĴ(}XM'J#+E'%|T˥s(JK02<8KPC|Rz~1z˺=(xdsN0싌&ui~5笥bq;Kv-yrB,YmXb͞U㙞p3(kXt%gPy{{VʤjPׂ"}x:`YZMCcWpԍ4B`ͅB\uR@tÃI7nUao58Dw	#j0~tWmxjx6ء5}?>}-jֱ6j^?C~c~]#b<@yQљ*n|t꧃ĽFGOu|,<9߹xL9bG-B	6CCp8|k)R,i݈s~^Y`̕rTU&F*J׋Mrp껶w[uy^6ޕPlkwjK(e!f-+Զj-jmsZPiV"e(*!R xB%8St&'x܋AH*舒#+$TET#(aTsCv]ʷkǎ[--^6#*D2;X>zєG6r$WiP>W$݈i%YgWVځJYφcɠ(2EtHFA.4#aQ2X'!)koai6J$R\1hRL-aR)td>mB웪#+@Y05	pbLYwn1MY[5v1w5sor3SEhcZְ720reoLAB[v)T.28bmd̵zI䅚%hi!AAs&@ I8,{LauQaNC#*,oW2dJ$ǌ8LUcrz}#+DnKWmvf#P{Se"r<|+CtxiPXmR*P4+#AH/ns%Wo^v,M˧ƂEkM\\!Q^lwM#+-+e`nQ4ws5^<R`yoh\(4)mC+-<+@쀫HH%XRDX5X20qnءmq6	fdYvVJjRFFFԡYUV54X>31eIV"ƅZkdwt#*#*9e81C᭽,-J`iRe6Ѣ>+W7&FI)/I%7 `Q36VfV5WƥL̐`Xg)Aj̀`$qaq.*enar"G$Yr,];;#(z}w*$	;D8d[<pM{2?#(I~lq$/)6P}EP|jvոJc-?yĠETRxK_?;D#*~:6XC&E_$<! o}P &hnGOW_x?FdNՀM]n|ba99q7>_m%#*W)7F60.;f6"qz=ȏ@N(RhA;zSsƎN%'p#(RTj"F,PPU o蘧za?}Ug*#+EY#(@Zb12T4LɬVMFѤXi13eE4٦#DTESPj%"hE3Fɰҩ#+#*DLmS!"*~'^"qb/%P{yNq}h	b{v j#*L$&#*4'G}V)'][A=sAp=EXH^C@wpc"a1-pfJAHl2>|1Br$bXL`LqG= a\,Ap#*Iq4{/ݫ9ꨍH-(FRcZC#(*h>h[&heMh-Z-ƬݫʥmwkzY>aIPhbSDiO%gj-asˣU!qtx:TQjB9Io$c-4"s-IcHUcd&NΞv1o^kWL7ܿDYљ%`vT,bb!GLzCסPj%3	Cx&SuĢ/שoHQ#+HRTL[_it6#x<mbH" <XCL`AB6#*Yؠ @#*	4/*2#(@#(.8&y!R@#(z'SOKIlL>ƂDHBK_Xlz<U.jG0l0R.y`?m#+ID,HxRD2<ޫj+#H^Z?]Uz\%]1?eQFLTRںx%='Ȩ:4MK.ն#*23#G2ҬIRSCK3T&12](tV8WKB/{,D#*_BqN6(P2U$$FȽ=EV;wzںZ&p̶z w%#	U#*iΨ0y#0)]궁myzhiʬx4H`J[tf00}>n"{)$DDRB(pv#nĹ?=dfqε,WMI8[	:SY5&gOo~`=^̯aL$!Me:9&Χiי#9a֜7M#DCIF*G|^ʤy\>,D"O3Oˏ3Y8*C#L#($h*сH#(0tPHnаdHȐi)D>xg*)z7	֘4	A$+.@owf5hi$8b mܵq55` v%^MDu삓@~?+x	Ő*QISSr(MH.DWVp4fЕH[m5#nT	lCt9r.kHDdE"EcK"B6L0lk3ZlK`Jpeq`gCG#+Bwc\uUikNx?G=$3K[Cr.L%ƷQ]#+t[C:J(8fr3ѕzdf3昔J4i ZZĦ6m#*CL;D-x	P+ލd#c<3<=݆8ܓSqG|ड!L7fvc`gt@o"Clb	e+,tᇉ$YX*+S4 ۰Ŧ#(xr3V2ethhYj	=W$Tdb#*ᷮHR!lm8SNt#0uf':v+T6'\h02:h3*MȾ0"$MCn1#+5QQ	K\k]0LlߪN65+:TzQ u$RK	VRdKfb]w&|#+/a\ַEhC>TݔcnR\S4rWw,#+z'"e9Τ	!*Tqd5]NJYeʏ'ϏmdUYɠXE2Gč̓sNqLJI0tWLn'N21a&"#*W3~OAf̖,ܚ@x@H:f(6!4ؒ9jV"4NQlinqAi"讒		8#+:ʲY<,օP`gf0 I0y~Ɯ1tip#+bVl[M]>0Ka@Q.r[Etͤr?K9D=\˃ȥ^kMoPEmNa+%n¶ћǿ4G4ױ*|9E;=aJH-`E퟈1Xavd֠lŚwBZ9)Pt`rLDh 6JR	S~[KK+rwN29]˷wnՠ$`FyрBγZ&8Y#+%Jah׈4E{Sf"YkyLgȋIdx:dO>s.h❓	_$ 0crي>f8-t&]kBTǶq#,'K*K#+pΒ=8Dhf#*!Ha#/#+0ARɬmu^iY#0in d\nŢ#(a&WX"1`l"⸺CEEca02J/e4Q3,TTD X!m(#*D#dCUqFQeAE:ևQ3bR#+P h׹T$#Lph`p.ȀĆ#@YhQ#*ND,	BnT*071G#()`q`c%!Mp8|3DE#+1 ;" }I|L{(4TDP#;12tIX{x!,"B@M@#(A~[Ѯ#(O-Eq[gp.Gi4'EAhSs!C(hڽH5;#*xl>"Fx_#**D&zHcBhre~o>	8k°P|n$9M\_awA*QE2	:ق/ݟ4]ӡ)vpvE7re	Z*PKj\D0GgvLTZ$`:bz'kJF8h4BP1X9E/7-ZZfp{\w*ջ$%o#(">1{ϒm1'=h{bXI6YM.<~xAjwky^v'uDt;M4vȌ6k#vךHI%#*AMז	HR#+@1#JԪThphf}ԙ"<:A?[O|Uz(L2	(6UfL $I;;y{5lFNo#(CY#*?tJIT4ffd!.a^{A#*8SdYPn(O.a5㼐SsX8o=飼쳳=)LQUsLB`4uzɑD֜פ:;`-W&B.YeS2m2n凈"5Br=䨗zITzvj7ћ0K'`^01)&Eb''kl#(C00Ƶuǒ2')PzڊJ5eҌDrkQjMQoim^M#(\iQHE/l,Q$DG( ,&#(;#(_w%T#(#(1yw-,h-BK߻9>Jfu3~#(~t`@$D	E#(fi}ݴxX+<	+|NttTXt#*S06DGd %ED19iRBfR a#+ $'IK3#(4*:]5ĳ^=QzOX`Ba>k<Xkl4$#+1F*f9&qHnl8sh>!&Ւ1D$PuS$c)!Bi*^<xtr	sQ@@ R^9<=PcIpFfuY7龃!GhMܡT\~mN'{ [Q#*pS}|"TPO2TBIMPg^81/˥>v/jF-TM+-hVY%M5jنl"ҍj߼qTB)Cnx5/灈vhv;ny: s zS_CTE&|=8ۿujSoJuw	n X_-D~]۸Ar:_>&W!]w}Xba"̂$V|色WS".YK|Bu|^4:B0C<PLmBgR؃0/&W"%$CijQVV!, #+-,IubffYhQ$z{a{Ӊ jD/fZcR}{kM0UUN	MϺ$r"a坽 P)eZA.(B.2>}:Y}4<F{0 DGc&ym(#(+Ǵ<P;#UG!#*d#PS<߯6XAŘ}wn2}:GR'#+ЂZ`>a{.V̌>JFoHl#(fȱ=?#*hٸWwt>Rt6DhfڌXcW?#*9UC#+|bl" :J;M'W#*B0$fOʊ.v2E_Oy6~^^yz65J*l-xY1Bn[6[[m]#+Z62۳#+=Cx3䕦S5|= =A,ȌQ`$ڵ{߇2IbBH00Ŋ@$w}HD1li66U~(L_ɛm\gR1BSĂXSlDTk/Qn"YmZ6̋`,]#($<#(EA`_j'IIீA5j#*=F\#(	>b"D7u@q2ay=Q+ױ#(JH;eC̠::n%ݴ"@K'jq`0Ԍː/Ș#+H&ci"MRjөSH*56װ"*Qt"PQ*S;""IKۨǫT|tgѫ0g-Y4b9-YĴl>Oؒͤ8Ȗop%dU(\t1@ww5TD7Xbkh ھY8&̙1*H5cESh߼-xPj#*#*#+gmճQ!	BG4#+E4LxB	KP>]DH*$(UjlH,<#*3o;wYd/^?bڅ!#('k>Lj ƀF2c7,i}Ьmbmq6#09Jykx~uMi56-+ƼVm%Ef̪뛶:Ȳ݌6ZM%LM#+#+a"J	 [tܷ/&,Eɩ2ʹZ]]ymƢFf[Ke-y6e0"Pe0`N! nXM 5UYjPjR)["A4cU @-֌a.T?:L1QB߉I#(hVF8<\zu)/ՀEE{FyCfU{]f)jsz<7ĸv;#M#*Rqt:żnaO3fBY QG)ȼ.#*Lo_jtrRM'?,n2)%": MZ:~V֠[@ڬ#ra4}T4/[ x	Kd)&3/S=fPIC"J݁'GǮ+$dz$,#Y2rbar9!56~,zl#(6dC#(Laf|8/u#*"ȘL3`eDhҷW0ܕZ<~w@6Q~féó	3ѺZXfxOOR6{#+3,?jJTدZ͵Pu_WpĮ^*ڜ:;Р8Sٲ~̗atñ#d*F8R!)rW\:ԍjأa}JaNAyB+9gf$#*D{!'U~#]Z@n?VB(ߗ  )w{6S|#*<"0	=fxae\L5JH#(>/ݲog?:W?WW_o??w_|қqw&5t]E\? n&@Bg+_M-#*^~~wbI!nA`-PUEPBMME8#(Z`~;{!H	?va\0{bA'W5H mgve<@#((y3g@j{őnYR8LAb鐁2a	N$׻g81VFw3{Rodg(4d*ea˜dLS<A@Z}LZqHvq7u#Q0*i憛ԤvSfZM3Z2iLfE80#*AKH#a#*pV=e`ZsmIiCG#+2.%gC#*s5L_##**&b%&edF-ty/9#(c.6}7TcQZ$;7).[*C3LJ.cbr0}rzXyu='=4,כyf	X#dq!Bv#+A4#BxRpc^F#+-%Mӏ]bUc@X*.0:'s#1@k6!5lvˆ*DuF@XtwܰH#(H#+iFpw;\e"] z7I{,v֢'Tt_}o'{LA\JCPU2ũ-Ji,1bk)B,0 ٙ=fDMVPREwJ@#(Oz:86a>\o1t4?ަ15وx:Rsq,]2GvԱ?fz1rr-GTJhTXqu7ɧ<}>"iw3heM*;7щ&Ǹ'Ƌ#*D'oYnZCkpe)Muy0)5a82ZMң[ҍ#T2A!%#gu+;C0Hl!C֠uTn@'Kb`ٰL)!q|TxUpXTs#+PtsC}E	{+Y^(G'ռ^!`C=Q#*vZDP`·mYjZ&IH8_hGG(80mցou-ᣣAO#(D*;H,(E-?T]#(U< &ZxvhOѲ:s_3{]@{'ÀN،vޡ4@U<^8!K'䗂l#adyф#عB٣נG_TtRAQ(vY]N*pAr9SCD22bKrk/ۧF,Q8UfKdWD>ǁY>z]7H34)$c	=!ӫO["w$S	r
#<==
#-----BEGIN PGP SIGNATURE-----\n\niQIcBAABCgAGBQJXb8XBAAoJEEm0xnwFJ3qqVd4P/0zGDejjwuhqyUX3KeVO2GUd\nmYmlDrjH5uoP9Zw5BvfK6fnzgr27DJN3WPQrwDJ+6vw8ikorZZavBBSSSI+aJLq3\njzUT3Kdjv+vj+/WZ1O61bWqSRGRSip7aeklcIL4QG8i9oTIracg0CfJRKqHSuffa\neJx3+lxX84JHJ8v9amFBjMwoDxcKAzv8NMQ9rb87x8sq5TkG5wCqV1BfKEqSey6o\nLQaZsafOCpIbdaPO41kYr6ehlcbQAsYebFLlI89FGWuRqDcewXVFuHHle2mKQEQP\nftQ94QSUiQC2Z+6PWxRm5vmpPhArkCJWSpfo4HIymM0oZ+raoCkJtSUUI2J8BCHf\nhU69uneulQ+V/7pZlbnR60/7lFJCiwP2cYzXjwCxcCvwmqCuNCa2smkXKfMqHPVP\n3lr7iv48e/oyY9Cin6SxqXWf9+mhyCvM+E4aP0t4K4yjuTQt5Has1EFMH+YLYt6F\nf59yphTY2AIPnssA15sjQMUhVktLcmSJ1HXEArn2KcvMKqd+ElXfYq8T8/LcWdpL\nWwV0yS51W6SZe6THmZN12AbiSG/+IOZ37K6KjWFrxwWcVyhrs2y9V9bnzazVkO5Q\naba7JFMVD9S4ZPcwiB9at4PUSMNLuznnCfUkktJfDVt0cU03qnkn9bePLtuK9jN+\nKQoh8dWLw4jIQiQNIM5t\n=7bjw\n-----END PGP SIGNATURE-----\n
